<?php
/**
 * @copyright    Copyright (C) 2009-2018 ACYBA SAS - All rights reserved..
 * @license        GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die('Restricted access');

class plgAcymailingdjclassifieds extends JPlugin{
	function __construct(&$subject, $config){
		parent::__construct($subject, $config);
		if(!isset($this->params)){
			$plugin = JPluginHelper::getPlugin('acymailing', 'djclassifieds');
			$this->params = new acyParameter($plugin->params);
		}

		//check if the component is installed
		$this->acypluginsHelper = acymailing_get('helper.acyplugins');
		$this->component_installed = file_exists(JPATH_SITE.DS.'components'.DS.'com_djclassifieds');
		if($this->component_installed){
			$this->fullLocations = acymailing_loadObjectList('SELECT id, parent_id, name FROM #__djcf_regions');
			$this->locations = array();
			foreach($this->fullLocations as $oneLoc){
				$this->locations[$oneLoc->parent_id][] = $oneLoc;
			}
		}
	}

	function acymailing_getPluginType(){
		if(!$this->component_installed || ($this->params->get('frontendaccess') == 'none' && !acymailing_isAdmin())) return;
		$onePlugin = new stdClass();
		$onePlugin->name = 'Dj-Classifieds';
		$onePlugin->function = 'acymailing_djclassifieds_show';
		$onePlugin->help = 'plugin-djclassifieds';
		return $onePlugin;
	}

	function acymailing_djclassifieds_show(){
		$config = acymailing_config();
		if(version_compare($config->get('version'), '5.6.5', '<')){
			acymailing_display('Please download and install the latest AcyMailing version otherwise this plugin will NOT work', 'error');
			return;
		}

		acymailing_loadLanguageFile('com_djclassifieds', JPATH_SITE.DS.'components'.DS.'com_djclassifieds');
		acymailing_loadLanguageFile('com_djclassifieds', JPATH_ADMINISTRATOR.DS.'components'.DS.'com_djclassifieds');

		$pageInfo = new stdClass();
		$pageInfo->filter = new stdClass();
		$pageInfo->filter->order = new stdClass();
		$pageInfo->limit = new stdClass();
		$pageInfo->elements = new stdClass();

		$paramBase = ACYMAILING_COMPONENT.'.djclassifieds';

		$pageInfo->filter->order->value = acymailing_getUserVar($paramBase.".filter_order", 'filter_order', 'a.id', 'cmd');
		$pageInfo->filter->order->dir = acymailing_getUserVar($paramBase.".filter_order_Dir", 'filter_order_Dir', 'desc', 'word');
		if(strtolower($pageInfo->filter->order->dir) !== 'desc') $pageInfo->filter->order->dir = 'asc';
		$pageInfo->search = acymailing_getUserVar($paramBase.".search", 'search', '', 'string');
		$pageInfo->search = strtolower(trim($pageInfo->search));
		$pageInfo->filter_cat = acymailing_getUserVar($paramBase.".filter_cat", 'filter_cat', '', 'int');
		$pageInfo->filter_type = acymailing_getUserVar($paramBase.".filter_type", 'filter_type', '', 'int');
		$pageInfo->limit->value = acymailing_getUserVar($paramBase.'.list_limit', 'limit', acymailing_getCMSConfig('list_limit'), 'int');
		$pageInfo->limit->start = acymailing_getUserVar($paramBase.'.limitstart', 'limitstart', 0, 'int');
		$pageInfo->automaxvalue = acymailing_getUserVar($paramBase.".max", 'max', '20', 'int');
		$pageInfo->contentfilter = acymailing_getUserVar($paramBase.".contentfilter", 'contentfilter', 'created', 'string');
		$pageInfo->contentorder = acymailing_getUserVar($paramBase.".contentorder", 'contentorder', 'id,DESC', 'string');
		$pageInfo->cols = acymailing_getUserVar($paramBase.".cols", 'cols', '1', 'string');
		$pageInfo->pictheight = acymailing_getUserVar($paramBase.".pictheight", 'pictheight', '150', 'string');
		$pageInfo->pictwidth = acymailing_getUserVar($paramBase.".pictwidth", 'pictwidth', '150', 'string');
		$pageInfo->pict = acymailing_getUserVar($paramBase.".pict", 'pict', '1', 'string');
		$pageInfo->autopict = acymailing_getUserVar($paramBase.".autopict", 'autopict', '1', 'string');
		$pageInfo->readmore = acymailing_getUserVar($paramBase.".readmore", 'readmore', '1', 'string');
		$pageInfo->readmoreauto = acymailing_getUserVar($paramBase.".readmoreauto", 'readmoreauto', '1', 'string');
		$pageInfo->wrap = acymailing_getUserVar($paramBase.".wrap", 'wrap', '0', 'string');
		$pageInfo->clickable = acymailing_getUserVar($paramBase.".clickable", 'clickable', '1', 'string');
		$pageInfo->clickableauto = acymailing_getUserVar($paramBase.".clickableauto", 'clickableauto', '1', 'string');
		$pageInfo->extrafieldsauto = acymailing_getUserVar($paramBase.".extrafieldsauto", 'extrafieldsauto', '1', 'string');
		$pageInfo->extrafields = acymailing_getUserVar($paramBase.".extrafields", 'extrafields', '1', 'string');
		$pageInfo->location = acymailing_getUserVar($paramBase.".location", 'location', '', 'string');
		$pageInfo->city = acymailing_getUserVar($paramBase.".city", 'city', '', 'string');
		$pageInfo->other = acymailing_getUserVar($paramBase.".other", 'other', '', 'string');

		$searchFields = array('a.id', 'a.name', 'b.id IS NOT NULL AND b.id', 'b.name IS NOT NULL AND b.name', 'c.username IS NOT NULL AND c.username', 'c.name IS NOT NULL AND c.name');

		if(!empty($pageInfo->search)){
			$searchVal = '\'%'.acymailing_getEscaped($pageInfo->search, true).'%\'';
			$filters[] = ' ( '.implode(" LIKE $searchVal ) OR ( ", $searchFields)." LIKE $searchVal )";
		}

		if($this->params->get('displayart', 'all') == 'onlypub'){
			$filters[] = "a.published = 1 AND (a.date_start = '0000-00-00 00:00:00' OR a.date_start < '".date('Y-m-d H:i:s', time())."') AND (a.date_exp = '0000-00-00 00:00:00' OR a.date_exp > '".date('Y-m-d H:i:s', time())."')";
		}

		if(!empty($pageInfo->filter_cat)){
			$filters[] = "a.cat_id = ".$pageInfo->filter_cat;
		}

		$query = 'SELECT SQL_CALC_FOUND_ROWS a.*, b.*, c.name AS username, a.name AS artname, a.alias AS artalias, a.id AS artid FROM `#__djcf_items` AS a ';
		$query .= 'LEFT JOIN #__djcf_categories AS b ON a.cat_id = b.id ';
		$query .= 'LEFT JOIN `#__users` AS c ON a.user_id = c.id';

		if(!empty($filters)){
			$query .= ' WHERE ('.implode(') AND (', $filters).')';
		}

		if(!empty($pageInfo->filter->order->value)){
			$query .= ' ORDER BY '.$pageInfo->filter->order->value.' '.$pageInfo->filter->order->dir;
		}

		$rows = acymailing_loadObjectList($query, '', $pageInfo->limit->start, $pageInfo->limit->value);

		if(!empty($pageInfo->search)){
			$rows = acymailing_search($pageInfo->search, $rows);
		}

		$pageInfo->elements->total = acymailing_loadResult('SELECT FOUND_ROWS()');
		$pageInfo->elements->page = count($rows);

		$pagination = new acyPagination($pageInfo->elements->total, $pageInfo->limit->start, $pageInfo->limit->value);

		$type = acymailing_getVar('string', 'type');

		?>
		<script language="javascript" type="text/javascript">
			<!--
			var selectedContents = new Array();
			function applyContent(contentid, rowClass){
				var tmp = selectedContents.indexOf(contentid)
				if(tmp != -1){
					window.document.getElementById('content' + contentid).className = rowClass;
					delete selectedContents[tmp];
				}else{
					window.document.getElementById('content' + contentid).className = 'selectedrow';
					selectedContents.push(contentid);
				}
				updateTag();
			}

			var selectedCat = new Array();
			function applyAuto(catid, rowClass){
				if(catid == 'all'){
					if(window.document.getElementById('cat' + catid).className == 'selectedrow'){
						window.document.getElementById('catall').className = rowClass;
					}else{
						window.document.getElementById('cat' + catid).className = 'selectedrow';
						for(key in selectedCat){
							if(!isNaN(key)){
								window.document.getElementById('cat' + key).className = rowClass;
								delete selectedCat[key];
							}
						}
					}
				}else{
					window.document.getElementById('catall').className = 'row0';
					if(selectedCat[catid]){
						window.document.getElementById('cat' + catid).className = rowClass;
						delete selectedCat[catid];
					}else{
						window.document.getElementById('cat' + catid).className = 'selectedrow';
						selectedCat[catid] = 'selectedone';
					}
				}
				updateTagAuto();
			}

			function updateTag(){
				var tag = '';
				var otherinfo = '';
				var tmp = 0;
				for(var i = 0; i < document.adminForm.cbaffiche.length; i++){
					if(document.adminForm.cbaffiche[i].checked){
						if(tmp == 0){
							tmp += 1;
							otherinfo += "|display:";
							otherinfo += document.adminForm.cbaffiche[i].value;
						}else{
							otherinfo += ",";
							otherinfo += document.adminForm.cbaffiche[i].value;
						}
					}
				}

				if(document.adminForm.extrafields){
					tmp = 0;
					for(var i = 0; i < document.adminForm.extrafields.length; i++){
						if(document.adminForm.extrafields[i].checked){
							if(tmp == 0){
								tmp += 1;
								otherinfo += "| extrafields:";
								otherinfo += document.adminForm.extrafields[i].value;
							}else{
								otherinfo += ",";
								otherinfo += document.adminForm.extrafields[i].value;
							}
						}
					}
				}

				for(var i = 0; i < document.adminForm.clickable.length; i++){
					if(document.adminForm.clickable[i].checked){
						otherinfo += '| clickable:' + document.adminForm.clickable[i].value;
					}
				}

				if(document.adminForm.wrap.value && document.adminForm.wrap.value != 0){
					otherinfo += "| wrap:" + document.adminForm.wrap.value;
				}

				for(var i = 0; i < document.adminForm.readmore.length; i++){
					if(document.adminForm.readmore[i].checked){
						otherinfo += '| readmore:' + document.adminForm.readmore[i].value;
					}
				}

				for(var i = 0; i < document.adminForm.pict.length; i++){
					if(document.adminForm.pict[i].checked){
						otherinfo += '| pict:' + document.adminForm.pict[i].value;

						if(document.adminForm.pict[i].value == 'resized'){
							document.getElementById('pictsize').style.display = '';
							if(document.adminForm.pictwidth.value) otherinfo += '| maxwidth:' + document.adminForm.pictwidth.value;
							if(document.adminForm.pictheight.value) otherinfo += '| maxheight:' + document.adminForm.pictheight.value;
						}else{
							document.getElementById('pictsize').style.display = 'none';
						}
					}
				}

				for(var i in selectedContents){
					if(selectedContents[i] && !isNaN(i)){
						tag = tag + '{djclassifieds:' + selectedContents[i] + otherinfo + '}<br />';
					}
				}
				setTag(tag);
			}


			function updateTagAuto(){
				var tag = '';
				var otherinfo = '';
				var tmp = 0;

				if(document.adminForm.other.value && document.adminForm.other.value != 0){
					otherinfo += "| location:" + document.adminForm.other.value;
				}else if(document.adminForm.city.value && document.adminForm.city.value != 0){
					otherinfo += "| location:" + document.adminForm.city.value;
				}else if(document.adminForm.location.value && document.adminForm.location.value != 0){
					otherinfo += "| location:" + document.adminForm.location.value;
				}

				for(var i = 0; i < document.adminForm.cbafficheauto.length; i++){
					if(document.adminForm.cbafficheauto[i].checked){
						if(tmp == 0){
							tmp += 1;
							otherinfo += "| display:";
							otherinfo += document.adminForm.cbafficheauto[i].value;
						}else{
							otherinfo += ",";
							otherinfo += document.adminForm.cbafficheauto[i].value;
						}
					}
				}

				if(document.adminForm.extrafieldsauto){
					tmp = 0;
					for(var i = 0; i < document.adminForm.extrafieldsauto.length; i++){
						if(document.adminForm.extrafieldsauto[i].checked){
							if(tmp == 0){
								tmp += 1;
								otherinfo += "| extrafields:";
								otherinfo += document.adminForm.extrafieldsauto[i].value;
							}else{
								otherinfo += ",";
								otherinfo += document.adminForm.extrafieldsauto[i].value;
							}
						}
					}
				}

				for(var i = 0; i < document.adminForm.clickableauto.length; i++){
					if(document.adminForm.clickableauto[i].checked){
						otherinfo += '| clickable:' + document.adminForm.clickableauto[i].value;
					}
				}

				if(document.adminForm.wrapauto.value && document.adminForm.wrapauto.value != 0){
					otherinfo += "| wrap:" + document.adminForm.wrapauto.value;
				}

				for(var i = 0; i < document.adminForm.readmoreauto.length; i++){
					if(document.adminForm.readmoreauto[i].checked){
						otherinfo += '| readmore:' + document.adminForm.readmoreauto[i].value;
					}
				}

				tmp = 0;
				for(var i = 0; i < document.adminForm.autopict.length; i++){
					if(document.adminForm.autopict[i].checked){
						otherinfo += '| pict:' + document.adminForm.autopict[i].value;
						if(document.adminForm.autopict[i].value == 'resized'){
							document.getElementById('pictsizeauto').style.display = '';
							if(document.adminForm.pictwidthauto.value) otherinfo += '| maxwidth:' + document.adminForm.pictwidthauto.value;
							if(document.adminForm.pictheightauto.value) otherinfo += '| maxheight:' + document.adminForm.pictheightauto.value;
						}else{
							document.getElementById('pictsizeauto').style.display = 'none';
						}
					}
				}

				if(document.adminForm.cols.value){
					otherinfo += "| cols:" + document.adminForm.cols.value;
				}
				if(document.adminForm.max_article.value){
					otherinfo += "| max_article:" + document.adminForm.max_article.value;
				}
				if(document.adminForm.contentorder.value){
					otherinfo += "| order:" + document.adminForm.contentorder.value;
				}
				<?php if($type == 'autonews'){ ?>
				if(document.adminForm.min_article.value){
					otherinfo += "| min_article:" + document.adminForm.min_article.value;
				}
				if(document.adminForm.contentfilter && document.adminForm.contentfilter.value){
					otherinfo += "| filter:" + document.adminForm.contentfilter.value;
				}
				<?php } ?>
				tag = '{autodjclassifieds:';
				for(var icat in selectedCat){
					if(selectedCat[icat] == 'selectedone'){
						tag += icat + '-';
					}
				}
				tag += otherinfo + '}<br />';
				setTag(tag);
			}
			//-->
		</script>
		<?php
		//we load custom fields
		$fields = 'SELECT id,label FROM `#__djcf_fields` ORDER BY label';
		$fields = acymailing_loadObjectList($fields);

		$choice = array();
		$choice[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$choice[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		$valImages = array();
		$valImages[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$valImages[] = acymailing_selectOption("resized", acymailing_translation('RESIZED'));
		$valImages[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		$ordering = array();
		$ordering[] = acymailing_selectOption("id,DESC", acymailing_translation('ACY_ID'));
		$ordering[] = acymailing_selectOption("date_start,DESC", acymailing_translation('CREATED_DATE'));
		$ordering[] = acymailing_selectOption("date_exp,DESC", acymailing_translation('EXPIRY_DATE'));
		$ordering[] = acymailing_selectOption("name,ASC", acymailing_translation('FIELD_TITLE'));
		$ordering[] = acymailing_selectOption("rand", acymailing_translation('ACY_RANDOM'));

		$contentfilter = array();
		$contentfilter[] = acymailing_selectOption("", acymailing_translation('ACY_ALL'));
		$contentfilter[] = acymailing_selectOption("created", acymailing_translation('ONLY_NEW_CREATED'));

		$column = array();
		for($i = 1; $i < 11; $i++){
			$column[] = acymailing_selectOption("$i", $i);
		}

		$tabs = acymailing_get('helper.acytabs');
		echo $tabs->startPane('docman_tab');
		echo $tabs->startPanel(acymailing_translation('TAG_ELEMENTS'), 'docman_listings');
		?>
		<br style="font-size:1px"/>
		<div class="onelineblockoptions">
			<table width="100%" class="acymailing_table">
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('DISPLAY'); ?></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbaffiche" value="title" id="title" checked="checked" onclick="updateTag();"/><label style="margin-left:5px" for="title" id="title-lbl"><?php echo acymailing_translation('ACY_TITLE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbaffiche" value="introtext" id="introtext" onclick="updateTag();"/><label style="margin-left:5px" for="introtext" id="introtext-lbl"><?php echo acymailing_translation('INTRO_TEXT'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbaffiche" value="description" id="description" checked="checked" onclick="updateTag();"/><label style="margin-left:5px" for="description" id="description-lbl"><?php echo acymailing_translation('ACY_DESCRIPTION'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbaffiche" value="image" id="image" onclick="updateTag();"/><label style="margin-left:5px" for="image" id="image-lbl"><?php echo acymailing_translation('ACY_IMAGE'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap"><input type="checkbox" name="cbaffiche" value="address" id="address" onclick="updateTag();"/><label style="margin-left:5px" for="address" id="address-lbl"><?php echo acymailing_translation('ADDRESSCAPTION'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbaffiche" value="price" id="price" onclick="updateTag();"/><label style="margin-left:5px" for="price" id="price-lbl"><?php echo acymailing_translation('COM_DJCLASSIFIEDS_PRICE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbaffiche" value="created" id="created" onclick="updateTag();"/><label style="margin-left:5px" for="created" id="created-lbl"><?php echo acymailing_translation('CREATED_DATE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbaffiche" value="createdby" id="createdby" onclick="updateTag();"/><label style="margin-left:5px" for="createdby" id="createdby-lbl"><?php echo acymailing_translation('AUTHOR_NAME'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap" colspan="4"><input type="checkbox" name="cbaffiche" value="cattitle" id="cattitle" onclick="updateTag();"/><label style="margin-left:5px" for="cattitle" id="cattitle-lbl"><?php echo acymailing_translation('COM_DJCLASSIFIEDS_PLEASE_SELECT_CATEGORY'); ?></label></td>
				</tr>
				<?php if(!empty($fields)){ ?>
					<tr>
						<td nowrap="nowrap"><?php echo acymailing_translation('EXTRA_FIELDS'); ?></td>
						<?php
						$tmp = 0;
						if(!empty($fields)){
							foreach($fields as $oneField){
								if($tmp == 4){
									echo '</tr><tr><td/>';
									$tmp = 0;
								}
								echo '<td><input type="checkbox" name="extrafields" value="'.intval($oneField->id).'" id="'.intval($oneField->id).'" onclick="updateTag();"/><label style="margin-left:5px" for="'.$oneField->id.'" id="'.$oneField->id.'-lbl">'.$oneField->label.'</label></td>';
								$tmp++;
							}
						}
						while($tmp != 4){
							echo '<td/>';
							$tmp++;
						}
						?>
					</tr>
				<?php } ?>
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
					<td colspan="2"><?php echo acymailing_radio($choice, 'clickable', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->clickable); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'readmore', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->readmore); ?>
				</tr>
				<tr>
					<td nowrap="nowrap" valign="top"><?php echo acymailing_translation('DISPLAY_PICTURES'); ?></td>
					<td nowrap="nowrap" colspan="2"><?php echo acymailing_radio($valImages, 'pict', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->pict); ?>
						<span id="pictsize" <?php if($pageInfo->pict != 'resized') echo 'style="display:none;"'; ?> ><br/>
							<?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
							<input name="pictwidth" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictwidth; ?>" style="width:30px;"/>
					x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
							<input name="pictheight" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictheight; ?>" style="width:30px;"/>
				</span>
					</td>
					<td nowrap="nowrap" valign="top" colspan="2"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="wrap" style="width:50px" value="0" onchange="updateTag();"/>'); ?></td>
				</tr>
			</table>
		</div>
		<div class="onelineblockoptions">
			<table class="acymailing_table_options">
				<tr>
					<td nowrap="nowrap" width="100%">
						<input placeholder="<?php echo acymailing_translation('ACY_SEARCH'); ?>" type="text" name="search" id="acymailingsearch" value="<?php echo $pageInfo->search; ?>" class="text_area" onchange="document.adminForm.submit();"/>
						<button class="acymailing_button_grey" onclick="this.form.submit();"><?php echo acymailing_translation('JOOMEXT_GO'); ?></button>
						<button class="acymailing_button_grey" onclick="document.getElementById('acymailingsearch').value='';this.form.submit();"><?php echo acymailing_translation('JOOMEXT_RESET'); ?></button>
					</td>
					<td nowrap="nowrap">
						<?php echo $this->_categories($pageInfo->filter_cat); ?>
					</td>
				</tr>
			</table>
			<!--====================================================================================LISTE DOCUMENTS===========================================================================-->
			<table class="acymailing_table" cellpadding="1" width="100%">
				<thead>
				<tr>
					<th/>
					<th class="title">
						<?php
						echo acymailing_gridSort(acymailing_translation('FIELD_TITLE'), 'a.name', $pageInfo->filter->order->dir, $pageInfo->filter->order->value);
						?>
					</th>
					<th class="title">
						<?php echo acymailing_gridSort(acymailing_translation('TAG_CATEGORIES'), 'b.name', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
					<th class="title titleid">
						<?php
						echo acymailing_gridSort(acymailing_translation('ACY_ID'), 'a.id', $pageInfo->filter->order->dir, $pageInfo->filter->order->value);
						?>
					</th>
				</tr>
				</thead>
				<tfoot>
				<tr>
					<td colspan="5">
						<?php echo $pagination->getListFooter(); ?>
						<?php echo $pagination->getResultsCounter(); ?>
					</td>
				</tr>
				</tfoot>
				<tbody>
				<?php
				$k = 0;
				if(!empty($rows)){
					foreach($rows as $row){
						?>
						<tr id="content<?php echo $row->artid; ?>" class="<?php echo "row$k"; ?>" onclick="applyContent(<?php echo $row->artid.",'row$k'" ?>);" style="cursor:pointer;">
							<td class="acytdcheckbox"></td>
							<td>
								<?php
								$text = '<b>'.acymailing_translation('JOOMEXT_ALIAS').' : </b>'.$row->artalias;
								if(!empty($row->username)) $text .= '<br /><b>'.acymailing_translation('ACY_USERNAME', true).' : </b>'.$row->username;
								echo acymailing_tooltip($text, $row->description, '', $row->artname);
								?>
							</td>
							<td>
								<?php
								if(!empty($row->name)){
									$text = '<b>'.acymailing_translation('TAG_CATEGORIES', true).' : </b>'.$row->name;
									echo acymailing_tooltip($text, $row->name, '', $row->name);
								}
								?>
							</td>
							<td align="center">
								<?php
								echo $row->artid;
								?>
							</td>
						</tr>
						<?php
						$k = 1 - $k;
					}
				}
				?>
				</tbody>
			</table>
		</div>
		<input type="hidden" name="boxchecked" value="0"/>
		<input type="hidden" name="filter_order" value="<?php echo $pageInfo->filter->order->value; ?>"/>
		<input type="hidden" name="filter_order_Dir" value="<?php echo $pageInfo->filter->order->dir; ?>"/>
		<?php

		echo $tabs->endPanel();
		echo $tabs->startPanel(acymailing_translation('TAG_CATEGORIES'), 'docman_auto');
		?>
		<br style="font-size:1px"/>
		<div class="onelineblockoptions">
			<table width="100%" class="acymailing_table">
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('DISPLAY'); ?></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbafficheauto" value="title" id="titleauto" checked="checked" onclick="updateTagAuto();"/><label style="margin-left:5px" for="titleauto" id="titleauto-lbl"><?php echo acymailing_translation('ACY_TITLE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbafficheauto" value="introtext" id="introtextauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="introtextauto" id="introtextauto-lbl"><?php echo acymailing_translation('INTRO_TEXT'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbafficheauto" value="description" id="descriptionauto" checked="checked" onclick="updateTagAuto();"/><label style="margin-left:5px" for="descriptionauto" id="descriptionauto-lbl"><?php echo acymailing_translation('ACY_DESCRIPTION'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap"><input type="checkbox" name="cbafficheauto" value="image" id="imageauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="imageauto" id="imageauto-lbl"><?php echo acymailing_translation('ACY_IMAGE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbafficheauto" value="address" id="addressauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="addressauto" id="addressauto-lbl"><?php echo acymailing_translation('ADDRESSCAPTION'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbafficheauto" value="price" id="priceauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="priceauto" id="priceauto-lbl"><?php echo acymailing_translation('COM_DJCLASSIFIEDS_PRICE'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap"><input type="checkbox" name="cbafficheauto" value="created" id="createdauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="createdauto" id="createdauto-lbl"><?php echo acymailing_translation('CREATED_DATE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbafficheauto" value="createdby" id="createdbyauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="createdbyauto" id="createdbyauto-lbl"><?php echo acymailing_translation('AUTHOR_NAME'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbafficheauto" value="cattitle" id="cattitleauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="cattitleauto" id="cattitleauto-lbl"><?php echo acymailing_translation('COM_DJCLASSIFIEDS_PLEASE_SELECT_CATEGORY'); ?></label></td>
				</tr>
				<?php if(!empty($fields)){ ?>
					<tr>
						<td nowrap="nowrap"><?php echo acymailing_translation('EXTRA_FIELDS'); ?></td>
						<?php
						$tmp = 0;
						if(!empty($fields)){
							foreach($fields as $oneField){
								if($tmp == 3){
									echo '</tr><tr><td/>';
									$tmp = 0;
								}
								echo '<td><input type="checkbox" name="extrafieldsauto" value="'.intval($oneField->id).'" id="'.intval($oneField->id).'auto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="'.$oneField->id.'auto" id="'.$oneField->id.'auto-lbl">'.$oneField->label.'</label></td>';
								$tmp++;
							}
						}
						while($tmp != 3){
							echo '<td/>';
							$tmp++;
						}
						?>
					</tr>
				<?php } ?>
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'clickableauto', 'size="1" onclick="updateTagAuto();"', 'value', 'text', $pageInfo->clickableauto); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'readmoreauto', 'size="1" onclick="updateTagAuto();"', 'value', 'text', $pageInfo->readmoreauto); ?>
				</tr>
				<tr>
					<td nowrap="nowrap" valign="top">
						<?php echo acymailing_translation('DISPLAY_PICTURES'); ?>
					</td>
					<td nowrap="nowrap"><?php echo acymailing_radio($valImages, 'autopict', 'size="1" onclick="updateTagAuto();"', 'value', 'text', $pageInfo->autopict); ?>
						<span id="pictsizeauto" <?php if($pageInfo->autopict != 'resized') echo 'style="display:none;"'; ?> ><br/>
							<?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
							<input name="pictwidthauto" type="text" onchange="updateTagAuto();" value="<?php echo $pageInfo->pictwidth; ?>" style="width:30px;"/>
					x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
							<input name="pictheightauto" type="text" onchange="updateTagAuto();" value="<?php echo $pageInfo->pictheight; ?>" style="width:30px;"/>
				</span>
					</td>
					<td nowrap="nowrap" valign="top" colspan="2"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="wrapauto" style="width:50px" value="0" onchange="updateTagAuto();"/>'); ?></td>
				</tr>
				<tr>
					<td nowrap="nowrap" nowrap="nowrap">
						<?php echo acymailing_translation('MAX_ARTICLE'); ?>
					</td>
					<td nowrap="nowrap">
						<input type="text" name="max_article" style="width:50px" value="<?php echo $pageInfo->automaxvalue; ?>" onchange="updateTagAuto();"/>
					</td>
					<td nowrap="nowrap">
						<?php echo acymailing_translation('ACY_ORDER'); ?>
					</td>
					<td nowrap="nowrap">
						<?php echo acymailing_select($ordering, 'contentorder', 'style="width:150px;" size="1" onchange="updateTagAuto();"', 'value', 'text', $pageInfo->contentorder); ?>
					</td>
				</tr>
				<tr>
					<td>
						<?php echo acymailing_translation('FIELD_COLUMNS'); ?>
					</td>
					<td nowrap="nowrap" colspan="3">
						<?php echo acymailing_select($column, 'cols', 'style="width:150px;" size="1" onchange="updateTagAuto();"', 'value', 'text', $pageInfo->cols); ?>
					</td>
				</tr>
				<?php if($type == 'autonews'){ ?>
					<tr>
						<td nowrap="nowrap">
							<?php echo acymailing_translation('MIN_ARTICLE'); ?>
						</td nowrap="nowrap">
						<td nowrap="nowrap">
							<input type="text" name="min_article" style="width:50px" value="1" onchange="updateTagAuto();"/>
						</td>
						<td nowrap="nowrap">
							<?php echo acymailing_translation('JOOMEXT_FILTER'); ?>
						</td>
						<td nowrap="nowrap">
							<?php echo acymailing_select($contentfilter, 'contentfilter', 'size="1" onchange="updateTagAuto();"', 'value', 'text', $pageInfo->contentfilter); ?>
						</td>
					</tr>
				<?php } ?>
			</table>
		</div>
		<script>
			<?php if(ACYMAILING_J30){ ?>
			function removeChosen(){
				jQuery("#location_chzn").remove();
				jQuery("#location").removeClass("chzn-done").show();
				jQuery("#city_chzn").remove();
				jQuery("#city").removeClass("chzn-done").show();
				jQuery("#other_chzn").remove();
				jQuery("#other").removeClass("chzn-done").show();
			}

			document.addEventListener("DOMContentLoaded", function(){
				removeChosen();
				setTimeout(function(){
					removeChosen();
				}, 100);
			});
			<?php } ?>

			function updateLocation(id, source){
				if(source == "country"){
					var options = document.querySelectorAll('#city option.locoption');

					for (var i = 0; i < options.length; ++i) {
						options[i].selected = false;
						if(id != 0 && options[i].className.indexOf('parent-'+id+'-loc') != -1){
							options[i].style.display = "";
						}else {
							options[i].style.display = "none";
						}
					}
				}

				var options = document.querySelectorAll('#other option.locoption');

				for (var i = 0; i < options.length; ++i) {
					options[i].selected = false;
					if(source == "city" && id != 0 && options[i].className.indexOf('parent-'+id+'-loc') != -1){
						options[i].style.display = "";
					}else {
						options[i].style.display = "none";
					}
				}
			}
		</script>
		<div class="onelineblockoptions">
			<span class="acyblocktitle"><?php echo acymailing_translation('COM_DJCLASSIFIEDS_LOCATION'); ?></span>
			<table width="100%" class="acymailing_table">
				<tr>
					<td>
						<?php echo acymailing_translation('COM_DJCLASSIFIEDS_COUNTRY'); ?>
					</td>
					<td>
						<?php
						$locations = acymailing_loadObjectList('SELECT id AS value, name AS text FROM #__djcf_regions WHERE parent_id = 0 AND published = 1');
						$default = (object)array('value' => 0, 'text' => '- - -');
						array_unshift($locations, $default);
						echo acymailing_select($locations, 'location', ' size="1" onchange="updateLocation(this.value, \'country\');updateTagAuto();"', 'value', 'text', $pageInfo->location);
						?>
					</td>
					<td>
						<label id="citylabel"><?php echo acymailing_translation('COM_DJCLASSIFIEDS_CITY'); ?></label>
					</td>
					<td>
						<select id="city" name="city" onchange="updateLocation(this.value, 'city');updateTagAuto();" >
							<option value="0">- - -</option>
							<?php
							foreach($this->fullLocations as $oneLoc){
								echo '<option class="locoption parent-'.$oneLoc->parent_id.'-loc" value="'.$oneLoc->id.'" ';
								if($pageInfo->city == $oneLoc->id && $pageInfo->location == $oneLoc->parent_id) echo 'selected="selected"';
								if(empty($pageInfo->location) || $pageInfo->location != $oneLoc->parent_id) echo ' style="display:none;" ';
								echo '>'.$oneLoc->name.'</option>';
							}
							?>
						</select>
					</td>
				</tr>
				<tr>
					<td>
						<label id="otherlabel"><?php echo acymailing_translation('COM_DJCLASSIFIEDS_OTHER'); ?></label>
					</td>
					<td colspan="3">
						<select id="other" name="other" onchange="updateTagAuto();" >
							<option value="0">- - -</option>
							<?php
							foreach($this->fullLocations as $oneLoc){
								echo '<option class="locoption parent-'.$oneLoc->parent_id.'-loc" value="'.$oneLoc->id.'" ';
								if($pageInfo->other == $oneLoc->id && $pageInfo->city == $oneLoc->parent_id) echo 'selected="selected"';
								if(empty($pageInfo->city) || $pageInfo->city != $oneLoc->parent_id) echo ' style="display:none;" ';
								echo '>'.$oneLoc->name.'</option>';
							}
							?>
						</select>
					</td>
				</tr>
			</table>
		</div>
		<!--====================================================================================LISTE CATEGORIES===========================================================================-->
		<div class="onelineblockoptions">
			<span class="acyblocktitle"><?php echo acymailing_translation('TAG_CATEGORIES'); ?></span>
			<table class="acymailing_table" cellpadding="1" width="100%">
				<?php $k = 0;
				?>
				<tr id="catall" class="<?php echo "row$k"; ?>" onclick="applyAuto('all','<?php echo "row$k" ?>');" style="cursor:pointer;">
					<td class="acytdcheckbox"></td>
					<td>
						<?php
						echo acymailing_translation('ACY_ALL');
						?>
					</td>
				</tr>
				<?php
				if(!empty($this->catvalues)){
					foreach($this->catvalues as $oneCat){
						if(empty($oneCat->value)) continue;
						?>
						<tr id="cat<?php echo $oneCat->value ?>" class="<?php echo "row$k"; ?>" onclick="applyAuto(<?php echo $oneCat->value ?>,'<?php echo "row$k" ?>');" style="cursor:pointer;">
							<td class="acytdcheckbox"></td>
							<td>
								<?php
								echo $oneCat->text;
								?>
							</td>
						</tr>
						<?php $k = 1 - $k;
					}
				} ?>
			</table>
		</div>
		<?php
		echo $tabs->endPanel();
		echo $tabs->endPane();
	}

	function _categories($filter_cat){
		//select all cats
		$mosetCats = acymailing_loadObjectList('SELECT id,parent_id,name FROM #__djcf_categories ORDER BY `id` ASC');
		$this->cats = array();
		if(!empty($mosetCats)){
			foreach($mosetCats as $oneCat){
				$this->cats[$oneCat->parent_id][] = $oneCat;
			}
		}
		$this->catvalues = array();
		$this->catvalues[] = acymailing_selectOption(0, acymailing_translation('ACY_ALL'));
		$this->_handleChildrens();
		return acymailing_select($this->catvalues, 'filter_cat', 'class="inputbox" size="1" onchange="document.adminForm.submit( );"', 'value', 'text', intval($filter_cat));
	}

	function _handleChildrens($parent_id = 0, $level = 0){
		if(!empty($this->cats[$parent_id])){
			foreach($this->cats[$parent_id] as $cat){
				$this->catvalues[] = acymailing_selectOption($cat->id, str_repeat(" - - ", $level).$cat->name);
				$this->_handleChildrens($cat->id, $level + 1);
			}
		}
	}

	function acymailing_replacetags(&$email){
		$this->_replaceAuto($email);
		$this->_replaceOne($email);
	}

	private function _replaceOne(&$email){

		//load the tags
		$tags = $this->acypluginsHelper->extractTags($email, 'djclassifieds');
		if(empty($tags)) return;

		
		acymailing_loadLanguageFile('com_djclassifieds', JPATH_SITE.DS.'components'.DS.'com_djclassifieds');

		//Set the read more text or image
		$this->readmore = empty($email->template->readmore) ? acymailing_translation('JOOMEXT_READ_MORE') : '<img src="'.ACYMAILING_LIVE.$email->template->readmore.'" alt="'.acymailing_translation('JOOMEXT_READ_MORE', true).'" />';

		//let's determine the Itemid
		$menuid = $this->params->get('itemid');
		if(empty($menuid)){
			$querymenu = 'SELECT id FROM #__menu WHERE link LIKE "%index.php?option=com_djclassifieds&view=item%" AND access = ';
			$querymenu .= ACYMAILING_J16 ? '1' : '0';
			$querymenu .= ' AND published = 1 LIMIT 1';

			$menuid = acymailing_loadResult($querymenu);
		}

		if(empty($menuid)){
			$this->itemId = '';
		}else{
			$this->itemId = '&Itemid='.$menuid;
		}

		// Get global currency
		$comparams = JComponentHelper::getParams('com_djclassifieds');
		$this->currency = $comparams->get('unit_price','EUR');
		$this->defaultImage = trim($comparams->get('blank_img_path','components/com_djclassifieds/assets/images'), '/').'/no-image-big.png';

		$tagsReplaced = array();
		foreach($tags as $i => $oneTag){
			if(isset($tagsReplaced[$i])) continue;
			$tagsReplaced[$i] = $this->_replaceContent($oneTag);
		}

		$this->acypluginsHelper->replaceTags($email, $tagsReplaced, true);
	}

	function _replaceContent(&$tag){
		if(!empty($tag->display)){
			$tmp = explode(',', strip_tags($tag->display));
			foreach($tmp as $onetmp){
				$tag->$onetmp = true;
			}
		}

		//2 : Load the article
		$query = 'SELECT a.*, c.name AS username, cat.name AS cattitle FROM `#__djcf_items` AS a LEFT JOIN `#__users` AS c ON a.user_id = c.id JOIN #__djcf_categories AS cat ON a.cat_id = cat.id WHERE a.id = '.intval($tag->id);

		$article = acymailing_loadObject($query);

		$result = '';
		//In case of we could not load the article for any reason...
		if(empty($article)){
			if(acymailing_isAdmin()) acymailing_enqueueMessage('The item "'.$tag->id.'" could not be loaded', 'notice');
			return $result;
		}
		$varFields = array();
		$varFields['{imagehtml}'] = '';
		foreach($article as $fieldName => $oneField){
			$varFields['{'.$fieldName.'}'] = $oneField;
		}

		$itemId = !empty($tag->itemid) ? '&Itemid='.$tag->itemid : $this->itemId;

		$link = 'index.php?option=com_djclassifieds&view=item&id='.$tag->id.$itemId;
		$link = acymailing_frontendLink($link);
		$varFields['{link}'] = $link;

		//Add the title with a link or not on it.
		$styleTitle = '<br /><h2 class="acymailing_title">';
		$styleTitleEnd = '</h2>';
		$resultTitle = '';
		if(!empty($tag->title)){
			if(!empty($tag->clickable)){
				$result = '<tr><td colspan="2" nowrap="nowrap"><a href="'.$link.'" target="_blank" >'.$styleTitle.$article->name.$styleTitleEnd.'</a></td></tr>';
			}else{
				$result = '<tr><td nowrap="nowrap">'.$styleTitle.$article->name.$styleTitleEnd.'</td></tr>';
			}
		}
		$text = '';
		if(!empty($tag->introtext) && !empty($article->intro_desc)){
			$text .= $article->intro_desc.' ';
		}

		if(!empty($tag->description) && !empty($article->description)){
			if(!empty($tag->introtext)) $text .= '<br /><br />';
			$text .= $article->description;
		}

		if(!empty($text)) $text = $this->acypluginsHelper->wrapText($text, $tag);

		$result .= '<tr><td class="fieldvalue" colspan="2" style="text-align:justify;">';
		if(!empty($tag->image)){
			$defaultImage = $this->params->get('defaultimage', 0) == 1 ? '<img style="float:left" src="'.$this->defaultImage.'"/>' : '';

			if(!empty($article->image_url)){
				$whereAreImages = 'components/com_djclassifieds/images';
				$image = explode(';', $article->image_url);
				$varFields['{imagehtml}'] = empty($image) ? $defaultImage : '<img style="float:left" src="'.$whereAreImages.'/'.htmlspecialchars($image[0]).'"/>';
			}else{
				$tableExists = acymailing_loadObjectList("SHOW TABLES LIKE '%djcf_images'");
				if(!empty($tableExists)){
					$image = acymailing_loadObject('SELECT * FROM #__djcf_images WHERE ordering = 1 AND type = "item" AND item_id = '.intval($tag->id));
					if(empty($image)){
						$imagePath = '';
					}else{
						$imagePath = trim($image->path, '/').'/'.$image->name.'.'.$image->ext;
						if(!file_exists(JPATH_SITE.DS.$imagePath)) $imagePath = trim($image->path, '/').'/'.$image->name.'_thb.'.$image->ext;
						if(!file_exists(JPATH_SITE.DS.$imagePath)) $imagePath = '';
					}
				}

				$varFields['{imagehtml}'] = empty($imagePath) ? $defaultImage : '<img style="float:left" src="'.$imagePath.'"/>';
			}
		}
		$result .= $varFields['{imagehtml}'].$text.'</td></tr>';

		if(!empty($tag->cattitle)){
			$result .= '<tr><td nowrap="nowrap" valign="top">'.acymailing_translation('COM_DJCLASSIFIEDS_PLEASE_SELECT_CATEGORY').' : </td><td><a target="_blank" href="index.php?option=com_djclassifieds&view=items&cid='.$article->cat_id.'">'.$article->cattitle.'</a></td></tr>';
		}

		if(!empty($tag->created)){
			$result .= '<tr><td nowrap="nowrap" valign="top">'.acymailing_translation('CREATED_DATE').' : </td><td>'.acymailing_getDate(acymailing_getTime($article->date_start), acymailing_translation('DATE_FORMAT_LC')).'</td></tr>';
		}

		if(!empty($tag->createdby) && !empty($article->username)){
			$result .= '<tr><td nowrap="nowrap">'.acymailing_translation('AUTHOR_NAME').' : </td><td>'.$article->username.'</td></tr>';
		}

		if(!empty($tag->price) && !empty($article->price)){
			$result .= '<tr><td nowrap="nowrap">'.acymailing_translation('COM_DJCLASSIFIEDS_PRICE').' : </td><td>'.$article->price.' '.(empty($article->currency) ? $this->currency : $article->currency).'</td></tr>';
		}

		if(!empty($tag->address)){
			//find location if exists
			$artloc = acymailing_loadObject('SELECT name FROM #__djcf_regions WHERE published = 1 AND id = '.intval($article->region_id).' LIMIT 1');
			$location = array();
			if(!empty($artloc)) $location[] = $artloc->name;
			if(!empty($article->address)) $location[] = $article->address;
			if(!empty($location)){
				$varFields['{location}'] = implode(' - ', $location);
				$result .= '<tr><td nowrap="nowrap">'.acymailing_translation('ADDRESSCAPTION').' : </td><td>'.$varFields['{location}'].'</td></tr>';
			}
		}

		if(!empty($tag->extrafields)){
			$tag->extrafields = explode(',', strip_tags($tag->extrafields));
			acymailing_arrayToInteger($tag->fields);
			//we load this item's extra fields
			$query = 'SELECT a.value, a.value_date, b.label, b.type '.'FROM #__djcf_fields_values AS a '.'JOIN #__djcf_fields AS b '.'ON a.field_id = b.id '.'WHERE a.item_id = '.intval($tag->id).' '.'AND a.field_id IN ('.implode(',', $tag->extrafields).')';
			$fields = acymailing_loadObjectList($query);
			if(!empty($fields)){
				foreach($fields as $oneField){
					if($oneField->type == 'checkbox' && !empty($oneField->value)){
						$oneField->value = explode(';', $oneField->value);
						foreach($oneField->value as $i => $oneValue){
							if(empty($oneValue)) unset($oneField->value[$i]);
						}
						$oneField->value = implode(', ', $oneField->value);
					}

					if(!empty($oneField->value)){
						$varFields['{cf|'.$oneField->label.'}'] = $oneField->value;
					}elseif(!empty($oneField->value_date) && $oneField->value_date != '0000-00-00'){
						$varFields['{cf|'.$oneField->label.'}'] = acymailing_getDate(acymailing_getTime($oneField->value_date), acymailing_translation('DATE_FORMAT_LC'));
					}
					if(!empty($varFields['{cf|'.$oneField->label.'}'])) $result .= '<tr><td nowrap="nowrap" valign="top">'.$oneField->label.' : </td><td valign="top">'.$varFields['{cf|'.$oneField->label.'}'].'</td></tr>';
				}
			}
		}

		if(isset($tag->pict) && $tag->pict == '0'){
			$pictureHelper = acymailing_get('helper.acypict');
			$result = $pictureHelper->removePictures($result);
		}

		if(!empty($tag->readmore)){
			$readMoreText = empty($this->readmore) ? acymailing_translation('JOOMEXT_READ_MORE') : $this->readmore;
			$result .= '<tr><td nowrap="nowrap" colspan="2"><a style="text-decoration:none;" target="_blank" href="'.$link.'"><span class="acymailing_readmore">'.$readMoreText.'</span></a></td></tr>';
		}

		$result = '<div class="acymailing_content" ><table cellspacing="0" cellpadding="0" border="0" width="100%">'.$result.'</table></div>';

		//in case of the user created his template
		if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'djclassifieds.php')){
			ob_start();
			require(ACYMAILING_MEDIA.'plugins'.DS.'djclassifieds.php');
			$result = ob_get_clean();
			$result = str_replace(array_keys($varFields), $varFields, $result);
		}

		$result = $this->acypluginsHelper->removeJS($result);
		$result = $this->acypluginsHelper->managePicts($tag, $result);
		$result = str_replace('administrator/', '', $result);
		return $result;
	}

	private function _replaceAuto(&$email){
		$this->acymailing_generateautonews($email);
		if(empty($this->tags)) return;
		$this->acypluginsHelper->replaceTags($email, $this->tags, true);
	}

	private function getSubLocations($parent_id){
		$children = array();
		if(empty($this->locations[$parent_id])) return $children;
		foreach($this->locations[$parent_id] as $child){
			$children[] = $child->id;
			$subChildren = $this->getSubLocations($child->id);
			$children = array_merge($children, $subChildren);
		}
		return $children;
	}

	function acymailing_generateautonews(&$email){
		$time = time();

		//load the tags
		$tags = $this->acypluginsHelper->extractTags($email, 'autodjclassifieds');
		$return = new stdClass();
		$return->status = true;
		$return->message = '';
		$this->tags = array();

		if(empty($tags)) return $return;

		foreach($tags as $oneTag => $parameter){
			if(isset($this->tags[$oneTag])) continue;

			$allcats = explode('-', $parameter->id);
			//we load the documents according to the tag
			$selectedArea = array();
			foreach($allcats as $oneCat){
				if(empty($oneCat)) continue;
				$selectedArea[] = intval($oneCat);
			}
			$query = 'SELECT id FROM #__djcf_items';
			$where = array();

			if(!empty($parameter->location)){
				$subLocations = $this->getSubLocations($parameter->location);
				$subLocations[] = intval($parameter->location);
				$where[] = 'region_id IN ('.implode(',', $subLocations).')';
			}

			if(!empty($selectedArea)) $where[] = 'cat_id IN ('.implode(',', $selectedArea).')';

			if(!empty($parameter->filter) && $parameter->filter == 'created'){
				$where[] = ' `date_start` > \''.date('Y-m-d H:i:s', $email->params['lastgenerateddate'] - date('Z')).'\'';
			}

			$where[] = "published = 1 AND (date_start = '0000-00-00 00:00:00' OR date_start < '".date('Y-m-d H:i:s', $time)."') AND (date_exp = '0000-00-00 00:00:00' OR date_exp > '".date('Y-m-d H:i:s', $time)."')";

			if(!empty($where)) $query .= ' WHERE ('.implode(') AND (', $where).')';

			if(!empty($parameter->order)){
				if($parameter->order == 'rand'){
					$query .= ' ORDER BY rand()';
				}else{
					$ordering = explode(',', $parameter->order);
					$query .= ' ORDER BY '.acymailing_secureField(trim($ordering[0])).' '.acymailing_secureField(trim($ordering[1]));
				}
			}

			if(!empty($parameter->max_article)){
				$query .= ' LIMIT '.intval($parameter->max_article);
			}elseif(empty($email->params['lastgenerateddate'])){
				$query .= ' LIMIT 20';
			}
			//We add a limit for the preview otherwise we could break everything

			$allArticles = acymailing_loadResultArray($query);

			if(!empty($parameter->min_article) && count($allArticles) < $parameter->min_article){
				//We won't generate the Newsletter
				$return->status = false;
				$return->message = 'Not enough content for the tag '.$oneTag.' : '.count($allArticles).' / '.$parameter->min_article.' between '.acymailing_getDate($email->params['lastgenerateddate']).' and '.acymailing_getDate($time);
			}

			$stringTag = '';
			if(!empty($allArticles)){
				if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'autodjclassifieds.php')){
					ob_start();
					require(ACYMAILING_MEDIA.'plugins'.DS.'autodjclassifieds.php');
					$stringTag = ob_get_clean();
				}else{
					$arrayElements = array();
					foreach($allArticles as $oneArticleId){
						$args = array();
						$args[] = 'djclassifieds:'.$oneArticleId;
						if(!empty($parameter->display)) $args[] = 'display:'.$parameter->display;
						if(!empty($parameter->clickable)) $args[] = 'clickable:'.$parameter->clickable;
						if(isset($parameter->extrafields)) $args[] = 'extrafields:'.$parameter->extrafields;
						if(!empty($parameter->wrap)) $args[] = 'wrap:'.$parameter->wrap;
						if(!empty($parameter->readmore)) $args[] = 'readmore:'.$parameter->readmore;
						if(isset($parameter->pict)) $args[] = 'pict:'.$parameter->pict;
						if(!empty($parameter->maxwidth)) $args[] = 'maxwidth:'.$parameter->maxwidth;
						if(!empty($parameter->maxheight)) $args[] = 'maxheight:'.$parameter->maxheight;
						if(!empty($parameter->itemid)) $args[] = 'itemid:'.$parameter->itemid;
						$arrayElements[] = '{'.implode('|', $args).'}';
					}
					$stringTag = $this->acypluginsHelper->getFormattedResult($arrayElements, $parameter);
				}
			}
			$this->tags[$oneTag] = $stringTag;
		}
		return $return;
	}
}//endclass
?>