<?php
/**
 * @copyright    Copyright (C) 2009-2018 ACYBA SAS - All rights reserved..
 * @license        GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die('Restricted access');

class plgAcymailingiproperty extends JPlugin{
	function __construct(&$subject, $config){
		parent::__construct($subject, $config);
		$this->name = 'iproperty';
		if(!isset($this->params)){
			$plugin = JPluginHelper::getPlugin('acymailing', $this->name);
			$this->params = new acyParameter($plugin->params);
		}

		//check if the component is installed
		$this->component_installed = file_exists(JPATH_SITE.DS.'components'.DS.'com_iproperty');
		$this->acypluginsHelper = acymailing_get('helper.acyplugins');

		if($this->component_installed) {
			$this->ispremium = !(bool)acymailing_loadResult('SELECT id FROM #__iproperty WHERE title = "" LIMIT 1');
		}
	}

	function acymailing_getPluginType(){
		if(!$this->component_installed || ($this->params->get('frontendaccess') == 'none' && !acymailing_isAdmin())) return;

		$onePlugin = new stdClass();
		//change the name
		$onePlugin->name = 'IProperty';
		$onePlugin->function = 'acymailing_'.$this->name.'_show';
		$onePlugin->help = 'plugin-'.$this->name;
		return $onePlugin;
	}

	//change the name
	function acymailing_iproperty_show(){
		$config = acymailing_config();

		if(version_compare($config->get('version'), '5.6.1', '<')){
			acymailing_display('Please download and install the latest AcyMailing version otherwise this plugin will NOT work', 'error');
			return;
		}

		
		acymailing_loadLanguageFile('com_iproperty', JPATH_SITE);

		$pageInfo = new stdClass();
		$pageInfo->filter = new stdClass();
		$pageInfo->filter->order = new stdClass();
		$pageInfo->limit = new stdClass();
		$pageInfo->elements = new stdClass();

		$paramBase = ACYMAILING_COMPONENT.'.'.$this->name;

		// don't forget to change the default order value if needed
		$pageInfo->filter->order->value = acymailing_getUserVar($paramBase.".filter_order", 'filter_order', 'a.id', 'cmd');
		$pageInfo->filter->order->dir = acymailing_getUserVar($paramBase.".filter_order_Dir", 'filter_order_Dir', 'desc', 'word');
		if(strtolower($pageInfo->filter->order->dir) !== 'desc') $pageInfo->filter->order->dir = 'asc';
		$pageInfo->search = acymailing_getUserVar($paramBase.".search", 'search', '', 'string');
		$pageInfo->search = strtolower(trim($pageInfo->search));
		$pageInfo->filter_cat = acymailing_getUserVar($paramBase.".filter_cat", 'filter_cat', '', 'int');
		$pageInfo->filter_type = acymailing_getUserVar($paramBase.".filter_type", 'filter_type', '', 'int');
		$pageInfo->limit->value = acymailing_getUserVar($paramBase.'.list_limit', 'limit', acymailing_getCMSConfig('list_limit'), 'int');
		$pageInfo->limit->start = acymailing_getUserVar($paramBase.'.limitstart', 'limitstart', 0, 'int');
		$pageInfo->contentfilter = acymailing_getUserVar($paramBase.".contentfilter", 'contentfilter', 'created', 'string');
		$pageInfo->contentorder = acymailing_getUserVar($paramBase.".contentorder", 'contentorder', 'id,DESC', 'string');
		$pageInfo->contentorderdir = acymailing_getUserVar($paramBase.".contentorderdir", 'contentorderdir', 'DESC', 'string');
		$pageInfo->cols = acymailing_getUserVar($paramBase.".cols", 'cols', '1', 'string');
		$pageInfo->pictheight = acymailing_getUserVar($paramBase.".pictheight", 'pictheight', '150', 'string');
		$pageInfo->pictwidth = acymailing_getUserVar($paramBase.".pictwidth", 'pictwidth', '150', 'string');
		$pageInfo->pict = acymailing_getUserVar($paramBase.".pict", 'pict', '1', 'string');
		$pageInfo->pictauto = acymailing_getUserVar($paramBase.".autopict", 'autopict', '1', 'string');
		$pageInfo->readmore = acymailing_getUserVar($paramBase.".readmore", 'readmore', '1', 'string');
		$pageInfo->readmoreauto = acymailing_getUserVar($paramBase.".readmoreauto", 'readmoreauto', '1', 'string');
		$pageInfo->wrap = acymailing_getUserVar($paramBase.".wrap", 'wrap', '0', 'string');
		$pageInfo->clickable = acymailing_getUserVar($paramBase.".clickable", 'clickable', '1', 'string');
		$pageInfo->clickableauto = acymailing_getUserVar($paramBase.".clickableauto", 'clickableauto', '1', 'string');
		$pageInfo->stype = acymailing_getUserVar($paramBase.".stypes", 'stypes', '1', 'string');

		//the query's start
		$query = 'SELECT SQL_CALC_FOUND_ROWS a.id AS propid, a.title AS proptitle, a.alias AS propalias, a.*, c.*, c.title AS cattitle '.'FROM #__iproperty AS a '.'JOIN #__iproperty_propmid AS b ON a.id = b.prop_id '.'JOIN #__iproperty_categories AS c ON b.cat_id = c.id ';

		//search fields...
		$searchFields = array('a.id', 'a.title', 'a.alias', 'c.title');

		//apply search fields
		if(!empty($pageInfo->search)){
			$searchVal = '\'%'.acymailing_getEscaped($pageInfo->search, true).'%\'';
			$filters[] = implode(" LIKE $searchVal OR ", $searchFields)." LIKE ".$searchVal;
		}

		//only published content ?
		if($this->params->get('displaycontent', 'all') == 'onlypub') $filters[] = "a.state = 1";

		//if the user filtered by category
		if(!empty($pageInfo->filter_cat)) $filters[] = 'b.cat_id = '.intval($pageInfo->filter_cat);

		//apply filters
		if(!empty($filters)) $query .= ' WHERE ('.implode(') AND (', $filters).')';

		$query .= ' GROUP BY a.id ';

		//apply ordering
		if(!empty($pageInfo->filter->order->value)) $query .= ' ORDER BY '.$pageInfo->filter->order->value.' '.$pageInfo->filter->order->dir;

		$rows = acymailing_loadObjectList($query, '', $pageInfo->limit->start, $pageInfo->limit->value);

		//yellow highlighting on search matches
		if(!empty($pageInfo->search)) $rows = acymailing_search($pageInfo->search, $rows);

		//pagination
		$pageInfo->elements->total = acymailing_loadResult('SELECT FOUND_ROWS()');
		$pageInfo->elements->page = count($rows);

		$pagination = new acyPagination($pageInfo->elements->total, $pageInfo->limit->start, $pageInfo->limit->value);

		//is this a Smart-Newsletter or a simple one ?
		$type = acymailing_getVar('string', 'type');

		?>
		<script language="javascript" type="text/javascript">
			<!--
			var selectedContents = new Array();
			function applyContent(contentid, rowClass){
				<?php
					//we insert contents in the order the user selected it
				?>
				var tmp = selectedContents.indexOf(contentid)
				if(tmp != -1){
					window.document.getElementById('content' + contentid).className = rowClass;
					delete selectedContents[tmp];
				}else{
					window.document.getElementById('content' + contentid).className = 'selectedrow';
					selectedContents.push(contentid);
				}
				updateTag();
			}

			var selectedCat = new Array();
			function applyAuto(catid, rowClass){
				if(catid == 'all'){
					if(window.document.getElementById('cat' + catid).className == 'selectedrow'){
						window.document.getElementById('catall').className = rowClass;
					}else{
						window.document.getElementById('cat' + catid).className = 'selectedrow';
						for(key in selectedCat){
							if(!isNaN(key)){
								window.document.getElementById('cat' + key).className = rowClass;
								delete selectedCat[key];
							}
						}
					}
				}else{
					window.document.getElementById('catall').className = 'row0';
					if(selectedCat[catid]){
						window.document.getElementById('cat' + catid).className = rowClass;
						delete selectedCat[catid];
					}else{
						window.document.getElementById('cat' + catid).className = 'selectedrow';
						selectedCat[catid] = 'selectedone';
					}
				}
				updateTagAuto();
			}

			function updateTag(){
				var tag = '';
				var otherinfo = '';
				var tmp = 0;

				<?php
					//add the fields the user want to be displayed
				?>
				for(var i = 0; i < document.adminForm.cbdisplay.length; i++){
					if(document.adminForm.cbdisplay[i].checked){
						if(tmp == 0){
							tmp += 1;
							otherinfo += "| display:";
							otherinfo += document.adminForm.cbdisplay[i].value;
						}else{
							otherinfo += ", ";
							otherinfo += document.adminForm.cbdisplay[i].value;
						}
					}
				}

				<?php
					//is the title clickable ?
				?>
				for(var i = 0; i < document.adminForm.clickable.length; i++){
					if(document.adminForm.clickable[i].checked && document.adminForm.clickable[i].value == '1'){
						otherinfo += '| link';
					}
				}

				<?php
					//do we have to wrap the text ? (description for example...)
				?>
				if(document.adminForm.wrap.value && document.adminForm.wrap.value != 0){
					otherinfo += "| wrap:" + document.adminForm.wrap.value;
				}

				<?php
					//do we have to add a "read more" button ?
				?>
				for(var i = 0; i < document.adminForm.readmore.length; i++){
					if(document.adminForm.readmore[i].checked && document.adminForm.readmore[i].value == '1'){
						otherinfo += '| readmore';
					}
				}

				<?php
					//picture management
				?>
				for(var i = 0; i < document.adminForm.pict.length; i++){
					if(document.adminForm.pict[i].checked){
						if(document.adminForm.pict[i].value != '0'){
							otherinfo += '| pict:' + document.adminForm.pict[i].value;
						}

						if(document.adminForm.pict[i].value == 'resized'){
							document.getElementById('pictsize').style.display = '';
							if(document.adminForm.pictwidth.value) otherinfo += '| maxwidth:' + document.adminForm.pictwidth.value;
							if(document.adminForm.pictheight.value) otherinfo += '| maxheight:' + document.adminForm.pictheight.value;
						}else{
							document.getElementById('pictsize').style.display = 'none';
						}
					}
				}

				<?php
					//insert the tags with the right order
				?>
				for(var i in selectedContents){
					if(selectedContents[i] && !isNaN(i)){
						tag = tag + '{<?php echo $this->name; ?>:' + selectedContents[i] + otherinfo + '}<br />';
					}
				}
				setTag(tag);
			}


			function updateTagAuto(){
				var tag = '';
				var otherinfo = '';
				var tmp = 0;

				for(var i = 0; i < document.adminForm.cbdisplayauto.length; i++){
					if(document.adminForm.cbdisplayauto[i].checked){
						if(tmp == 0){
							tmp += 1;
							otherinfo += "| display:";
							otherinfo += document.adminForm.cbdisplayauto[i].value;
						}else{
							otherinfo += ", ";
							otherinfo += document.adminForm.cbdisplayauto[i].value;
						}
					}
				}

				for(var i = 0; i < document.adminForm.clickableauto.length; i++){
					if(document.adminForm.clickableauto[i].checked && document.adminForm.clickableauto[i].value == '1'){
						otherinfo += '| link';
					}
				}

				if(document.adminForm.wrapauto.value && document.adminForm.wrapauto.value != 0){
					otherinfo += "| wrap:" + document.adminForm.wrapauto.value;
				}

				for(var i = 0; i < document.adminForm.readmoreauto.length; i++){
					if(document.adminForm.readmoreauto[i].checked && document.adminForm.readmoreauto[i].value == '1'){
						otherinfo += '| readmore';
					}
				}

				tmp = 0;
				for(var i = 0; i < document.adminForm.autopict.length; i++){
					if(document.adminForm.autopict[i].checked){
						if(document.adminForm.autopict[i].value != '0'){
							otherinfo += '| pict:' + document.adminForm.autopict[i].value;
						}

						if(document.adminForm.autopict[i].value == 'resized'){
							document.getElementById('pictsizeauto').style.display = '';
							if(document.adminForm.pictwidthauto.value) otherinfo += '| maxwidth:' + document.adminForm.pictwidthauto.value;
							if(document.adminForm.pictheightauto.value) otherinfo += '| maxheight:' + document.adminForm.pictheightauto.value;
						}else{
							document.getElementById('pictsizeauto').style.display = 'none';
						}
					}
				}

				if(document.adminForm.stype.value && document.adminForm.stype.value != 0){
					otherinfo += "| stype:" + document.adminForm.stype.value;
				}

				<?php
					//on how many columns do we have to display the contents ?
				?>
				if(document.adminForm.cols.value){
					otherinfo += "| cols:" + document.adminForm.cols.value;
				}

				<?php
					//limit the number of content displayed
				?>
				if(document.adminForm.max_article.value){
					otherinfo += "| max:" + document.adminForm.max_article.value;
				}

				<?php
					//with what order will we display the contents
				?>
				if(document.adminForm.contentorder.value){
					otherinfo += "| order:" + document.adminForm.contentorder.value + "," + document.adminForm.contentorderdir.value;
				}

				<?php if($type == 'autonews'){

					//minimum number of content for the newsletter to be displayed... yes, a perfect english !
				?>
				if(document.adminForm.min_article.value){
					otherinfo += "| min:" + document.adminForm.min_article.value;
				}

				<?php
					//filter the content : only newly created/modified
				?>
				if(document.adminForm.contentfilter && document.adminForm.contentfilter.value != 0){
					otherinfo += "| filter:" + document.adminForm.contentfilter.value;
				}
				<?php }
					//insert the tag
				?>
				tag = '{auto<?php echo $this->name; ?>:';
				for(var icat in selectedCat){
					if(selectedCat[icat] == 'selectedone'){
						tag += icat + '-';
					}
				}
				tag += otherinfo + '}<br />';

				setTag(tag);
			}
			//-->
		</script>
		<?php
		// yes/no for the options
		$choice = array();
		$choice[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$choice[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		// picture options
		$valImages = array();
		$valImages[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$valImages[] = acymailing_selectOption("resized", acymailing_translation('RESIZED'));
		$valImages[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		// filter options
		$contentfilter = array();
		$contentfilter[] = acymailing_selectOption("0", acymailing_translation('ACY_ALL'));
		$contentfilter[] = acymailing_selectOption("created", acymailing_translation('ONLY_NEW_CREATED'));
		$contentfilter[] = acymailing_selectOption("modified", acymailing_translation('ONLY_NEW_MODIFIED'));

		// options for the Nb. columns dropdown (1 to 10)
		$column = array();
		for($i = 1; $i < 11; $i++){
			$column[] = acymailing_selectOption("$i", $i);
		}

		$results = acymailing_loadObjectList('SELECT id, name FROM #__iproperty_stypes');
		$stype = array();
		$stype[] = acymailing_selectOption(0, acymailing_translation('ACY_ALL'));
		foreach($results as $oneStype){
			$stype[] = acymailing_selectOption($oneStype->id, $oneStype->name);
		}

		$tabs = acymailing_get('helper.acytabs');

		echo $tabs->startPane($this->name.'_tab');

		// start the first tab
		echo $tabs->startPanel(acymailing_translation('TAG_ELEMENTS'), $this->name.'_listings');
		?>
		<br style="font-size:1px"/>
		<div class="onelineblockoptions">
			<table width="100%" class="acymailing_smalltable">
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('DISPLAY'); ?></td>
					<?php if($this->ispremium){ ?>
						<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="title" id="title" checked="checked" onclick="updateTag();"/><label style="margin-left:5px" for="title"><?php echo acymailing_translation('ACY_TITLE'); ?></label></td>
					<?php }else{ ?>
						<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="amenities" id="amenities" checked="checked" onclick="updateTag();"/><label style="margin-left:5px" for="amenities"><?php echo acymailing_translation('COM_IPROPERTY_AMENITIES'); ?></label></td>
					<?php } ?>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="address" id="address" checked="checked" onclick="updateTag();"/><label style="margin-left:5px" for="address"><?php echo acymailing_translation('COM_IPROPERTY_ADDRESS'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="description" id="description" checked="checked" onclick="updateTag();"/><label style="margin-left:5px" for="description"><?php echo acymailing_translation('COM_IPROPERTY_DESCRIPTION'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="oldprice" id="oldprice" onclick="updateTag();"/><label style="margin-left:5px" for="oldprice"><?php echo acymailing_translation('Original price'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="price" checked="checked" id="price" onclick="updateTag();"/><label style="margin-left:5px" for="price"><?php echo acymailing_translation('COM_IPROPERTY_PRICE'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="image" id="image" checked="checked" onclick="updateTag();"/><label style="margin-left:5px" for="image"><?php echo acymailing_translation('ACY_IMAGE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="location" id="location" onclick="updateTag();"/><label style="margin-left:5px" for="location"><?php echo acymailing_translation('COM_IPROPERTY_LOCATION'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="beds" id="beds" checked="checked" onclick="updateTag();"/><label style="margin-left:5px" for="beds"><?php echo acymailing_translation('COM_IPROPERTY_BEDS'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="baths" id="baths" checked="checked" onclick="updateTag();"/><label style="margin-left:5px" for="baths"><?php echo acymailing_translation('COM_IPROPERTY_BATHS'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="lotsize" id="lotsize" checked="checked" onclick="updateTag();"/><label style="margin-left:5px" for="lotsize"><?php echo acymailing_translation('COM_IPROPERTY_LOT_SIZE'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="lotacres" id="lotacres" onclick="updateTag();"/><label style="margin-left:5px" for="lotacres"><?php echo acymailing_translation('COM_IPROPERTY_LOT_ACRES'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="lottype" id="lottype" onclick="updateTag();"/><label style="margin-left:5px" for="lottype"><?php echo acymailing_translation('COM_IPROPERTY_LOT_TYPE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="heat" id="heat" onclick="updateTag();"/><label style="margin-left:5px" for="heat"><?php echo acymailing_translation('COM_IPROPERTY_HEAT'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="cooling" id="cooling" onclick="updateTag();"/><label style="margin-left:5px" for="cooling"><?php echo acymailing_translation('COM_IPROPERTY_COOL'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="fuel" id="fuel" onclick="updateTag();"/><label style="margin-left:5px" for="fuel"><?php echo acymailing_translation('COM_IPROPERTY_FUEL'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="siding" id="siding" onclick="updateTag();"/><label style="margin-left:5px" for="siding"><?php echo acymailing_translation('COM_IPROPERTY_SIDING'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="reception" id="reception" onclick="updateTag();"/><label style="margin-left:5px" for="reception"><?php echo acymailing_translation('COM_IPROPERTY_RECEPTION'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="roof" id="roof" onclick="updateTag();"/><label style="margin-left:5px" for="roof"><?php echo acymailing_translation('COM_IPROPERTY_ROOF'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="yearbuilt" id="yearbuilt" onclick="updateTag();"/><label style="margin-left:5px" for="yearbuilt"><?php echo acymailing_translation('COM_IPROPERTY_YEAR_BUILT'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="zoning" id="zoning" onclick="updateTag();"/><label style="margin-left:5px" for="zoning"><?php echo acymailing_translation('COM_IPROPERTY_ZONING'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="vendor" id="vendor" onclick="updateTag();"/><label style="margin-left:5px" for="vendor"><?php echo acymailing_translation('COM_IPROPERTY_AGENTS'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="style" id="style" onclick="updateTag();"/><label style="margin-left:5px" for="style"><?php echo acymailing_translation('COM_IPROPERTY_STYLE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="schooldistrict" id="schooldistrict" onclick="updateTag();"/><label style="margin-left:5px" for="schooldistrict"><?php echo acymailing_translation('COM_IPROPERTY_SCHOOL_DISTRICT'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="garagetype" id="garagetype" onclick="updateTag();"/><label style="margin-left:5px" for="garagetype"><?php echo acymailing_translation('COM_IPROPERTY_GARAGE_TYPE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="garagesize" id="garagesize" onclick="updateTag();"/><label style="margin-left:5px" for="garagesize"><?php echo acymailing_translation('COM_IPROPERTY_GARAGE_SIZE'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="categories" id="categories" onclick="updateTag();"/><label style="margin-left:5px" for="categories"><?php echo acymailing_translation('ACY_CATEGORY'); ?></label></td>
					<?php if($this->ispremium){ ?>
							<td nowrap="nowrap" colspan="4"><input type="checkbox" name="cbdisplay" value="amenities" id="amenities" checked="checked" onclick="updateTag();"/><label style="margin-left:5px" for="amenities"><?php echo acymailing_translation('COM_IPROPERTY_AMENITIES'); ?></label></td>
					<?php }else{ ?>
							<td colspan="4"></td>
					<?php } ?>
				</tr>
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
					<td colspan="2"><?php echo acymailing_radio($choice, 'clickable', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->clickable); ?></td>
					<td/>
					<td nowrap="nowrap"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'readmore', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->readmore); ?>
				</tr>
				<tr>
					<td nowrap="nowrap" valign="top"><?php echo acymailing_translation('DISPLAY_PICTURES'); ?></td>
					<td nowrap="nowrap" colspan="3"><?php echo acymailing_radio($valImages, 'pict', 'size="1" onclick="updateTag();"', 'value', 'text', $pageInfo->pict); ?>
						<span id="pictsize" <?php if($pageInfo->pict != 'resized') echo 'style="display:none;"'; ?> ><br/>
							<?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
							<input name="pictwidth" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictwidth; ?>" style="width:30px;"/>
							x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
							<input name="pictheight" type="text" onchange="updateTag();" value="<?php echo $pageInfo->pictheight; ?>" style="width:30px;"/>
						</span>
					</td>
					<td nowrap="nowrap" colspan="2"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="wrap" style="width:50px" value="0" onchange="updateTag();"/>'); ?></td>
				</tr>
			</table>
		</div>
		<div class="onelineblockoptions">
			<table class="acymailing_table_options">
				<tr>
					<td nowrap="nowrap" width="100%">
						<input placeholder="<?php echo acymailing_translation('ACY_SEARCH'); ?>" type="text" name="search" id="acymailingsearch" value="<?php echo $pageInfo->search; ?>" class="text_area" onchange="document.adminForm.submit();"/>
						<button class="acymailing_button" onclick="this.form.submit();"><?php echo acymailing_translation('JOOMEXT_GO'); ?></button>
						<button class="acymailing_button" onclick="document.getElementById('acymailingsearch').value='';this.form.submit();"><?php echo acymailing_translation('JOOMEXT_RESET'); ?></button>
					</td>
					<td nowrap="nowrap">
						<?php echo $this->_categories($pageInfo->filter_cat); ?>
					</td>
				</tr>
			</table>
			<table class="acymailing_table" cellpadding="1" width="100%">
				<thead>
				<tr>
					<th/>
					<th class="title">
						<?php
						echo acymailing_gridSort(acymailing_translation('FIELD_TITLE'), 'a.title', $pageInfo->filter->order->dir, $pageInfo->filter->order->value);
						?>
					</th>
					<th class="title">
						<?php echo acymailing_gridSort(acymailing_translation('COM_IPROPERTY_PRICE'), 'a.price', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
					<th class="title">
						<?php echo acymailing_gridSort(acymailing_translation('TAG_CATEGORIES'), 'c.title', $pageInfo->filter->order->dir, $pageInfo->filter->order->value); ?>
					</th>
					<th class="title titleid">
						<?php
						echo acymailing_gridSort(acymailing_translation('ACY_ID'), 'a.id', $pageInfo->filter->order->dir, $pageInfo->filter->order->value);
						?>
					</th>
				</tr>
				</thead>
				<tfoot>
				<tr>
					<td colspan="5">
						<?php echo $pagination->getListFooter(); ?>
						<?php echo $pagination->getResultsCounter(); ?>
					</td>
				</tr>
				</tfoot>
				<tbody>
				<?php
				$k = 0;
				if(!empty($rows)){
					foreach($rows as $row){
						// change "postid"
						?>
						<tr id="content<?php echo $row->propid; ?>" class="<?php echo "row$k"; ?>" onclick="applyContent(<?php echo $row->propid.",'row$k'" ?>);" style="cursor:pointer;">
							<td class="acytdcheckbox"></td>
							<td>
								<?php
								// change field title
								if(!empty($row->proptitle)){
									echo $row->proptitle;
								}elseif(!empty($row->propalias)){
									echo $row->propalias;
								}
								?>
							</td>
							<td>
								<?php if(!empty($row->price)) echo $row->price; ?>
							</td>
							<td>
								<?php
								// change field title
								if(!empty($row->cattitle)){
									echo $row->cattitle;
								}
								?>
							</td>
							<td align="center" style="text-align:center">
								<?php
								// change field title
								echo $row->propid;
								?>
							</td>
						</tr>
						<?php
						// this enables to know if we have to set the line background grey or white
						$k = 1 - $k;
					}
				}
				?>
				</tbody>
			</table>
		</div>
		<input type="hidden" name="boxchecked" value="0"/>
		<input type="hidden" name="filter_order" value="<?php echo $pageInfo->filter->order->value; ?>"/>
		<input type="hidden" name="filter_order_Dir" value="<?php echo $pageInfo->filter->order->dir; ?>"/>
		<?php

		echo $tabs->endPanel();

		// start category tab
		echo $tabs->startPanel(acymailing_translation('TAG_CATEGORIES'), $this->name.'_auto');
		?>
		<br style="font-size:1px"/>
		<div class="onelineblockoptions">
			<table width="100%" class="acymailing_smalltable">
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('DISPLAY'); ?></td>
					<?php if($this->ispremium){ ?>
						<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="title" id="titleauto" checked="checked" onclick="updateTagAuto();"/><label style="margin-left:5px" for="titleauto"><?php echo acymailing_translation('ACY_TITLE'); ?></label></td>
					<?php }else{ ?>
						<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="amenities" id="amenitiesauto" checked="checked" onclick="updateTagAuto();"/><label style="margin-left:5px" for="amenitiesauto"><?php echo acymailing_translation('COM_IPROPERTY_AMENITIES'); ?></label></td>
					<?php } ?>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="address" id="addressauto" checked="checked" onclick="updateTagAuto();"/><label style="margin-left:5px" for="addressauto"><?php echo acymailing_translation('COM_IPROPERTY_ADDRESS'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="description" id="descriptionauto" checked="checked" onclick="updateTagAuto();"/><label style="margin-left:5px" for="descriptionauto"><?php echo acymailing_translation('COM_IPROPERTY_DESCRIPTION'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="oldprice" id="oldpriceauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="oldpriceauto"><?php echo acymailing_translation('Original price'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="price" id="priceauto" checked="checked" onclick="updateTagAuto();"/><label style="margin-left:5px" for="priceauto"><?php echo acymailing_translation('COM_IPROPERTY_PRICE'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="image" id="imageauto" checked="checked" onclick="updateTagAuto();"/><label style="margin-left:5px" for="imageauto"><?php echo acymailing_translation('ACY_IMAGE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="location" id="locationauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="locationauto"><?php echo acymailing_translation('COM_IPROPERTY_LOCATION'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="beds" id="bedsauto" checked="checked" onclick="updateTagAuto();"/><label style="margin-left:5px" for="bedsauto"><?php echo acymailing_translation('COM_IPROPERTY_BEDS'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="baths" id="bathsauto" checked="checked" onclick="updateTagAuto();"/><label style="margin-left:5px" for="bathsauto"><?php echo acymailing_translation('COM_IPROPERTY_BATHS'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="lotsize" id="lotsizeauto" checked="checked" onclick="updateTagAuto();"/><label style="margin-left:5px" for="lotsizeauto"><?php echo acymailing_translation('COM_IPROPERTY_LOT_SIZE'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="lotacres" id="lotacresauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="lotacresauto"><?php echo acymailing_translation('COM_IPROPERTY_LOT_ACRES'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="lottype" id="lottypeauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="lottypeauto"><?php echo acymailing_translation('COM_IPROPERTY_LOT_TYPE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="heat" id="heatauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="heatauto"><?php echo acymailing_translation('COM_IPROPERTY_HEAT'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="cooling" id="coolingauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="coolingauto"><?php echo acymailing_translation('COM_IPROPERTY_COOL'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="fuel" id="fuelauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="fuelauto"><?php echo acymailing_translation('COM_IPROPERTY_FUEL'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="siding" id="sidingauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="sidingauto"><?php echo acymailing_translation('COM_IPROPERTY_SIDING'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="reception" id="receptionauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="receptionauto"><?php echo acymailing_translation('COM_IPROPERTY_RECEPTION'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="roof" id="roofauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="roofauto"><?php echo acymailing_translation('COM_IPROPERTY_ROOF'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="yearbuilt" id="yearbuiltauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="yearbuiltauto"><?php echo acymailing_translation('COM_IPROPERTY_YEAR_BUILT'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="zoning" id="zoningauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="zoningauto"><?php echo acymailing_translation('COM_IPROPERTY_ZONING'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="vendor" id="vendorauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="vendorauto"><?php echo acymailing_translation('COM_IPROPERTY_AGENTS'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="style" id="styleauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="styleauto"><?php echo acymailing_translation('COM_IPROPERTY_STYLE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="schooldistrict" id="schooldistrictauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="schooldistrictauto"><?php echo acymailing_translation('COM_IPROPERTY_SCHOOL_DISTRICT'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="garagetype" id="garagetypeauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="garagetypeauto"><?php echo acymailing_translation('COM_IPROPERTY_GARAGE_TYPE'); ?></label></td>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="garagesize" id="garagesizeauto" onclick="updateTagAuto();"/><label style="margin-left:5px" for="garagesizeauto"><?php echo acymailing_translation('COM_IPROPERTY_GARAGE_SIZE'); ?></label></td>
				</tr>
				<tr>
					<td/>
					<td nowrap="nowrap"><input type="checkbox" name="cbdisplayauto" value="categories" id="categoriesauto" onclick="updateTag();"/><label style="margin-left:5px" for="categoriesauto"><?php echo acymailing_translation('ACY_CATEGORY'); ?></label></td>
					<?php if($this->ispremium){ ?>
						<td nowrap="nowrap" colspan="4"><input type="checkbox" name="cbdisplayauto" value="amenities" id="amenitiesauto" checked="checked" onclick="updateTagAuto();"/><label style="margin-left:5px" for="amenitiesauto"><?php echo acymailing_translation('COM_IPROPERTY_AMENITIES'); ?></label></td>
					<?php }else{ ?>
						<td colspan="4"></td>
					<?php } ?>
				</tr>
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('CLICKABLE_TITLE'); ?></td>
					<td nowrap="nowrap" colspan="2"><?php echo acymailing_radio($choice, 'clickableauto', 'size="1" onclick="updateTagAuto();"', 'value', 'text', $pageInfo->clickableauto); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td nowrap="nowrap" colspan="2"><?php echo acymailing_radio($choice, 'readmoreauto', 'size="1" onclick="updateTagAuto();"', 'value', 'text', $pageInfo->readmoreauto); ?>
				</tr>
				<tr>
					<td nowrap="nowrap" valign="top">
						<?php echo acymailing_translation('DISPLAY_PICTURES'); ?>
					</td>
					<td nowrap="nowrap" colspan="2"><?php echo acymailing_radio($valImages, 'autopict', 'size="1" onclick="updateTagAuto();"', 'value', 'text', $pageInfo->pictauto); ?>
						<span id="pictsizeauto" <?php if($pageInfo->pictauto != 'resized') echo 'style="display:none;"'; ?> ><br/>
							<?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
							<input name="pictwidthauto" type="text" onchange="updateTagAuto();" value="<?php echo $pageInfo->pictwidth; ?>" style="width:30px;"/>
					x <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
							<input name="pictheightauto" type="text" onchange="updateTagAuto();" value="<?php echo $pageInfo->pictheight; ?>" style="width:30px;"/>
				</span>
					</td>
					<td nowrap="nowrap" colspan="3"><?php echo acymailing_translation_sprintf('TRUNCATE_AFTER', '<input type="text" name="wrapauto" style="width:50px" value="0" onchange="updateTagAuto();"/>'); ?></td>
				</tr>
				<tr>
					<td>
						<?php echo acymailing_translation('COM_IPROPERTY_SALE_TYPE'); ?>
					</td>
					<td nowrap="nowrap" colspan="2">
						<?php echo acymailing_select($stype, 'stype', 'size="1" onchange="updateTagAuto();" style="width:150px;"', 'value', 'text', $pageInfo->stype); ?>
					</td>
					<td>
						<?php echo acymailing_translation('FIELD_COLUMNS'); ?>
					</td>
					<td nowrap="nowrap" colspan="2">
						<?php echo acymailing_select($column, 'cols', 'size="1" onchange="updateTagAuto();" style="width:150px;"', 'value', 'text', $pageInfo->cols); ?>
					</td>
				</tr>
				<tr>
					<td nowrap="nowrap" nowrap="nowrap">
						<?php echo acymailing_translation('MAX_ARTICLE'); ?>
					</td>
					<td nowrap="nowrap" colspan="2">
						<input type="text" name="max_article" style="width:50px" value="20" onchange="updateTagAuto();"/>
					</td>
					<td nowrap="nowrap">
						<?php echo acymailing_translation('ACY_ORDER'); ?>
					</td>
					<td nowrap="nowrap" colspan="2">
						<?php
						$values = array('id' => 'ACY_ID', 'created' => 'CREATED_DATE', 'modified' => 'MODIFIED_DATE', 'title' => 'FIELD_TITLE', 'price' => 'COM_IPROPERTY_PRICE');
						echo $this->acypluginsHelper->getOrderingField($values, $pageInfo->contentorder, $pageInfo->contentorderdir);
						?>
					</td>
				</tr>
				<?php if($type == 'autonews'){ ?>
					<tr>
						<td nowrap="nowrap">
							<?php echo acymailing_translation('MIN_ARTICLE'); ?>
						</td nowrap="nowrap">
						<td nowrap="nowrap" colspan="2">
							<input type="text" name="min_article" style="width:50px" value="1" onchange="updateTagAuto();"/>
						</td>
						<td nowrap="nowrap">
							<?php echo acymailing_translation('JOOMEXT_FILTER'); ?>
						</td>
						<td nowrap="nowrap" colspan="2">
							<?php echo acymailing_select($contentfilter, 'contentfilter', 'size="1" onchange="updateTagAuto();" style="width:150px;"', 'value', 'text', $pageInfo->contentfilter); ?>
						</td>
					</tr>
				<?php } ?>
			</table>
		</div>
		<!--====================================================================================LISTE CATEGORIES===========================================================================-->
		<div class="onelineblockoptions">
			<table class="acymailing_table" cellpadding="1" width="100%">
				<?php $k = 0;
				?>
				<tr id="catall" class="<?php echo "row$k"; ?>" onclick="applyAuto('all','<?php echo "row$k" ?>');" style="cursor:pointer;">
					<td class="acytdcheckbox"></td>
					<td>
						<?php
						echo acymailing_translation('ACY_ALL');
						?>
					</td>
				</tr>
				<?php
				if(!empty($this->catvalues)){
					foreach($this->catvalues as $oneCat){
						if(empty($oneCat->value)) continue;
						?>
						<tr id="cat<?php echo $oneCat->value ?>" class="<?php echo "row$k"; ?>" onclick="applyAuto(<?php echo $oneCat->value ?>,'<?php echo "row$k" ?>');" style="cursor:pointer;">
							<td class="acytdcheckbox"></td>
							<td>
								<?php
								echo $oneCat->text;
								?>
							</td>
						</tr>
						<?php $k = 1 - $k;
					}
				} ?>
			</table>
		</div>
		<?php
		echo $tabs->endPanel();
		echo $tabs->endPane();
	}

	function _categories($filter_cat){
		//select all cats
		$mosetCats = acymailing_loadObjectList('SELECT id,parent AS parent_id,title FROM #__iproperty_categories ORDER BY id ASC');
		$this->cats = array();
		if(!empty($mosetCats)){
			foreach($mosetCats as $oneCat){
				$this->cats[$oneCat->parent_id][] = $oneCat;
			}
		}

		$this->catvalues = array();
		$this->catvalues[] = acymailing_selectOption(0, acymailing_translation('ACY_ALL'));
		$this->_handleChildrens();
		return acymailing_select($this->catvalues, 'filter_cat', 'class="inputbox" size="1" onchange="document.adminForm.submit( );"', 'value', 'text', intval($filter_cat));
	}

	function _handleChildrens($parent_id = 0, $level = 0){
		if(empty($this->cats[$parent_id])) return;
		foreach($this->cats[$parent_id] as $cat){
			$this->catvalues[] = acymailing_selectOption($cat->id, str_repeat(" - - ", $level).$cat->title);
			$this->_handleChildrens($cat->id, $level + 1);
		}
	}

	function acymailing_replacetags(&$email){
		$this->_replaceAuto($email);
		$this->_replaceOne($email);
	}

	function _replaceOne(&$email){
		//load the tags
		$tags = $this->acypluginsHelper->extractTags($email, $this->name);
		if(empty($tags)) return;

		
		acymailing_loadLanguageFile('com_iproperty', JPATH_SITE);

		//We will need the mailer class as well
		$this->mailerHelper = acymailing_get('helper.mailer');

		//Set the read more text or image
		$this->readmore = empty($email->template->readmore) ? acymailing_translation('JOOMEXT_READ_MORE') : '<img src="'.ACYMAILING_LIVE.$email->template->readmore.'" alt="'.acymailing_translation('JOOMEXT_READ_MORE', true).'" />';

		if(file_exists(JPATH_ADMINISTRATOR.DS.'components'.DS.'com_iproperty'.DS.'classes'.DS.'admin.class.php')) {
			include_once(JPATH_ADMINISTRATOR . DS . 'components' . DS . 'com_iproperty' . DS . 'classes' . DS . 'admin.class.php');
			$this->ipropSettings = ipropertyAdmin::config();
		}

		$htmlreplace = array();
		$textreplace = array();
		$subjectreplace = array();
		foreach($tags as $i => $params){
			if(isset($htmlreplace[$i])) continue;
			$content = $this->_replaceContent($tags[$i], $email);
			$htmlreplace[$i] = $content;
			$textreplace[$i] = $this->mailerHelper->textVersion($content, true);
			$subjectreplace[$i] = strip_tags($content);
		}
		$email->body = str_replace(array_keys($htmlreplace), $htmlreplace, $email->body);
		$email->altbody = str_replace(array_keys($textreplace), $textreplace, $email->altbody);
		$email->subject = str_replace(array_keys($subjectreplace), $subjectreplace, $email->subject);
	}

	function _replaceContent(&$tag, $email){

		// extract the fields selected
		if(!empty($tag->display)){
			$tag->display = explode(',', $tag->display);

			foreach($tag->display as $i => $oneDisplay){
				$oneDisplay = trim($oneDisplay);
				$tag->$oneDisplay = true;
			}
			unset($tag->display);
		}

		// load content

		$query = 'SELECT a.*, b.title AS statename, c.title AS countryname 
					FROM #__iproperty AS a 
					LEFT JOIN #__iproperty_states AS b ON a.locstate = b.id 
					LEFT JOIN #__iproperty_countries AS c ON a.country = c.id 
					WHERE a.id = '.intval($tag->id).' LIMIT 1';
		$content = acymailing_loadObject($query);

		//In case of we could not load the article for any reason...
		if(empty($content)){
			if(acymailing_isAdmin()) acymailing_enqueueMessage('The content "'.$tag->id.'" could not be loaded', 'notice');
			return '';
		}

		if(!empty($this->ipropSettings) && $this->ipropSettings->baths_fraction === '0') $content->baths = intval($content->baths);

		$varFields = array();
		foreach($content as $fieldName => $oneField){
			$varFields['{'.$fieldName.'}'] = $oneField;
		}

		// create the link for the title and the read more button
		$link = 'index.php?option=com_iproperty&view=property&id='.$tag->id;
		if(!empty($tag->itemid)) $link .= '&Itemid='.$tag->itemid;
		if(!empty($email->language)) $link .= '&lang='.$email->language;
		$link = acymailing_frontendLink($link);
		$varFields['{link}'] = $link;

		$result = '<div class="acymailing_content acymailing_'.$this->name.'"><table cellspacing="0" cellpadding="0" border="0" width="100%">';

		// display the title
		if(!empty($tag->title) && !empty($content->title)){
			$result .= '<tr><td colspan="4"><h2 class="acymailing_title">';
			if(!empty($tag->link)) $result .= '<a href="'.$link.'">';
			$result .= $content->title;
			if(!empty($tag->link)) $result .= '</a>';
			$result .= '</h2></td></tr>';
		}

		if(!empty($tag->address)){
			$result .= '<tr><td colspan="4">';
			if(!$this->ispremium){
				$result .= '<h2 class="acymailing_title">';
				if(!empty($tag->link)) $result .= '<a href="'.$link.'">';
			}
			$address = array();
			if(!empty($content->street_num)) $address[] = $content->street_num;
			if(!empty($content->street)) $address[] = $content->street;
			if(!empty($content->street2)) $address[] = $content->street2;
			if(!empty($content->apt)) $address[] = $content->apt;
			$result .= '<strong>'.acymailing_translation('COM_IPROPERTY_LOCATION').':</strong> '.implode(' ', $address);
			if(!$this->ispremium){
				if(!empty($tag->link)) $result .= '</a>';
				$result .= '</h2>';
			}
			$result .= '</td></tr>';
		}

		if(!(empty($tag->oldprice) && empty($tag->price))){
			$content->currency = acymailing_loadObject('SELECT currency, currency_pos FROM #__iproperty_settings LIMIT 1');
			$content->currency->currencyleft = ($content->currency->currency_pos == 0) ? $content->currency->currency : '';
			$content->currency->currencyright = empty($content->currency->currencyleft) ? $content->currency->currency : '';

			$price = array();

			$thousand = ',';
			$digits = '.';
			if($this->ipropSettings->nformat == 1){
				$thousand = '.';
				$digits = ',';
			}

			$content->price2 = number_format($content->price2,  $this->ipropSettings->currency_digits, $thousand, $digits);
			$content->price = number_format($content->price,  $this->ipropSettings->currency_digits, $thousand, $digits);

			if(!empty($content->price2) && !empty($tag->oldprice)){
				$price[] = '<strike>'.$content->currency->currencyleft.$content->price2.$content->currency->currencyright.'</strike> ';
			}
			if(!empty($content->price) && !empty($tag->price)){
				$price[] = $content->currency->currencyleft.$content->price.$content->currency->currencyright.(empty($content->stype_freq) ? '' : '/'.$content->stype_freq);
			}
			if(!empty($price)){
				$varFields['{price}'] = implode(' ', $price);
				$result .= '<tr><td colspan="4"><strong>'.acymailing_translation('COM_IPROPERTY_PRICE').':</strong> '.implode(' ', $price).'</td></tr>';
			}
		}

		if(!empty($tag->categories)){
			$query = 'SELECT cat.title, cat.id 
						FROM #__iproperty_categories AS cat 
						JOIN #__iproperty_propmid AS pm ON pm.cat_id = cat.id 
						WHERE pm.prop_id = '.intval($tag->id);
			$categories = acymailing_loadObjectList($query);

			$outPut = array();
			foreach($categories as $oneCat){
				$outPut[] = '<a href="'.acymailing_frontendLink('index.php?option=com_iproperty&view=cat&id='.$oneCat->id).'" target="_blank">'.$oneCat->title.'</a>';
			}

			$varFields['{categories}'] = implode(', ', $outPut);
			$result .= '<tr><td colspan="4"><strong>'.acymailing_translation('TAG_CATEGORIES').':</strong> '.implode(', ', $outPut).'</td></tr>';
		}

		// display the main text wraped or not
		$varFields['{image}'] = '';
		if((!empty($tag->description) && !empty($content->description)) || !empty($tag->image)){
			$result .= '<tr><td colspan="4" class="acymailing_description">';
			if(!empty($tag->image)){
				$query = 'SELECT b.* 
							FROM #__iproperty_images AS b 
							WHERE b.propid = '.intval($tag->id).' 
							ORDER BY b.ordering ASC ';
				$mainPict = acymailing_loadObject($query);
				if(!empty($mainPict)){
					$varFields['{image}'] = '<img style="float:left; margin-right:10px;" src="'.trim($mainPict->path, '/').'/'.$mainPict->fname.$mainPict->type.'"/>';
					$result .= '<img style="float:left; margin-right:10px;" src="'.trim($mainPict->path, '/').'/'.$mainPict->fname.$mainPict->type.'"/>';
				}
			}

			if(!empty($tag->description)) $result .= $this->acypluginsHelper->wrapText($content->description, $tag);

			$result .= '</td></tr>';
		}

		$allInformation = array();

		if(!empty($tag->beds) && !empty($content->beds)){
			$allInformation['beds'] = array(acymailing_translation('COM_IPROPERTY_BEDS'), $content->beds);
		}

		if(!empty($tag->baths) && !empty($content->baths)){
			$allInformation['baths'] = array(acymailing_translation('COM_IPROPERTY_BATHS'), $content->baths);
		}

		if(!empty($tag->lotsize) && !empty($content->lotsize)){
			$allInformation['lotsize'] = array(acymailing_translation('COM_IPROPERTY_LOT_SIZE'), $content->lotsize);
		}

		if(!empty($tag->lotacres) && !empty($content->lot_acres)){
			$allInformation['lotacres'] = array(acymailing_translation('COM_IPROPERTY_LOT_ACRES'), $content->lot_acres);
		}

		if(!empty($tag->lottype) && !empty($content->lot_type)){
			$allInformation['lottype'] = array(acymailing_translation('COM_IPROPERTY_LOT_TYPE'), $content->lot_type);
		}

		if(!empty($tag->heat) && !empty($content->heat)){
			$allInformation['heat'] = array(acymailing_translation('COM_IPROPERTY_HEAT'), $content->heat);
		}

		if(!empty($tag->cooling) && !empty($content->cool)){
			$allInformation['cooling'] = array(acymailing_translation('COM_IPROPERTY_COOL'), $content->cool);
		}

		if(!empty($tag->fuel) && !empty($content->fuel)){
			$allInformation['fuel'] = array(acymailing_translation('COM_IPROPERTY_FUEL'), $content->fuel);
		}

		if(!empty($tag->siding) && !empty($content->siding)){
			$allInformation['siding'] = array(acymailing_translation('COM_IPROPERTY_SIDING'), $content->siding);
		}

		if(!empty($tag->roof) && !empty($content->roof)){
			$allInformation['roof'] = array(acymailing_translation('COM_IPROPERTY_ROOF'), $content->roof);
		}

		if(!empty($tag->reception) && !empty($content->reception)){
			$allInformation['reception'] = array(acymailing_translation('COM_IPROPERTY_RECEPTION'), $content->reception);
		}

		if(!empty($tag->yearbuilt) && !empty($content->yearbuilt)){
			$allInformation['yearbuilt'] = array(acymailing_translation('COM_IPROPERTY_YEAR_BUILT'), $content->yearbuilt);
		}

		if(!empty($tag->zoning) && !empty($content->zoning)){
			$allInformation['zoning'] = array(acymailing_translation('COM_IPROPERTY_ZONING'), $content->zoning);
		}

		if(!empty($tag->schooldistrict) && !empty($content->school_district)){
			$allInformation['schooldistrict'] = array(acymailing_translation('COM_IPROPERTY_SCHOOL_DISTRICT'), $content->school_district);
		}

		if(!empty($tag->garagetype) && !empty($content->garage_type)){
			$allInformation['garagetype'] = array(acymailing_translation('COM_IPROPERTY_GARAGE_TYPE'), $content->garage_type);
		}

		if(!empty($tag->garagesize) && !empty($content->garage_size)){
			$allInformation['garagesize'] = array(acymailing_translation('COM_IPROPERTY_GARAGE_SIZE'), $content->garage_size);
		}

		if(!empty($tag->vendor)){
			$query = 'SELECT a.fname, a.lname, a.id AS vid, c.name, c.id AS cid '.'FROM #__iproperty_agents AS a '.'JOIN #__iproperty_agentmid AS b '.'ON a.id = b.agent_id '.'JOIN #__iproperty_companies AS c '.'ON a.company = c.id '.'WHERE b.prop_id = '.intval($tag->id);
			$vendor = acymailing_loadObject($query);
			$allInformation['vendor'] = array(acymailing_translation('COM_IPROPERTY_AGENTS'), '<a href="index.php?option=com_iproperty&view=agentproperties&id='.$vendor->vid.'">'.$vendor->fname.' '.$vendor->lname.'</a>, <a href="index.php?option=com_iproperty&view=companyproperties&id='.$vendor->cid.'">'.$vendor->name.'</a>');
		}

		if(!empty($tag->location)){
			$location = array();
			$address = array();
			if(!empty($content->street_num)){
				$address[] = $content->street_num;
			}
			if(!empty($content->street)){
				$address[] = $content->street;
			}
			if(!empty($content->street2)){
				$address[] = $content->street2;
			}
			if(!empty($content->apt)){
				$address[] = $content->apt;
			}
			if(!empty($address)){
				$location[] = implode(' ', $address);
			}
			$address = array();
			if(!empty($content->postcode)){
				$address[] = $content->postcode;
			}
			if(!empty($content->city)){
				$address[] = $content->city;
			}
			if(!empty($address)){
				$location[] = implode(' ', $address);
			}
			if(!empty($content->province)){
				$location[] = $content->province;
			}
			if(!empty($content->statename)){
				$location[] = $content->statename;
			}
			if(!empty($content->countryname)){
				$location[] = $content->countryname;
			}
			if(!empty($location)){
				$allInformation['location'] = array(acymailing_translation('COM_IPROPERTY_LOCATION'), implode('<br />', $location));
			}
		}

		if(!empty($allInformation)){
			$cpt = 0;
			foreach($allInformation as $oneInfo){
				if($cpt % 2 == 0) $result .= '<tr>';

				$result .= '<td valign="top" nowrap="nowrap" style="text-align:right;padding-right:5px;"><b>'.$oneInfo[0].' </b></td><td>'.$oneInfo[1].'</td>';

				if($cpt % 2 != 0) $result .= '</tr>';

				$cpt++;
			}

			if($cpt % 2 != 0) $result .= '<td/></tr>';
		}

		if(!empty($tag->amenities) && isset($content->reception)){
			$query = 'SELECT a.* 
						FROM #__iproperty_amenities AS a 
						LEFT JOIN #__iproperty_propmid AS pm ON pm.amen_id = a.id 
						WHERE pm.prop_id = '.intval($tag->id).' 
						ORDER BY a.title ASC';
			$allAmenities = acymailing_loadObjectList($query);
			$amenities = array();
			foreach($allAmenities as $oneAmenity){
				$amenities[] = '<td nowrap="nowrap"> - '.$oneAmenity->title.'</td>';
			}

			if(!empty($amenities)){
				$result .= '<tr><td colspan="4"><b>'.acymailing_translation('COM_IPROPERTY_AMENITIES').' :</b></td></tr>';
				$cpt = 0;
				foreach($amenities as $oneInfo){
					if($cpt % 4 == 0) $result .= '<tr>';

					$result .= $oneInfo;

					if($cpt % 4 == 3) $result .= '</tr>';

					$cpt++;
				}

				if($cpt % 4 != 0) $result .= str_repeat('<td/>', $cpt % 4).'</tr>';
			}
		}

		if(!empty($tag->readmore)){
			$varFields['{readmore}'] = '<a style="text-decoration:none;" target="_blank" href="'.$link.'"><span class="acymailing_readmore">'.$this->readmore.'</span></a>';
			$result .= '<tr><td colspan="2"><br />'.$varFields['{readmore}'].'</td></tr>';
		}

		$result .= '</table></div><br />';

		// load the custom template if exists
		if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.$this->name.'.php')){
			ob_start();
			require(ACYMAILING_MEDIA.'plugins'.DS.$this->name.'.php');
			$result = ob_get_clean();
			$result = str_replace(array_keys($varFields), $varFields, $result);
		}

		// always remove JS, there is no JS in newsletters...
		$result = $this->acypluginsHelper->removeJS($result);

		//resize or remove pictures
		if(!isset($tag->pict)) $tag->pict = 0;
		$result = $this->acypluginsHelper->managePicts($tag, $result);

		return $result;
	}

	function _replaceAuto(&$email){
		$this->acymailing_generateautonews($email);
		if(empty($this->tags)) return;
		$this->acypluginsHelper->replaceTags($email, $this->tags, true);
	}

	function acymailing_generateautonews(&$email){
		//load the tags
		$tags = $this->acypluginsHelper->extractTags($email, 'auto'.$this->name);
		$return = new stdClass();
		$return->status = true;
		$return->message = '';
		$this->tags = array();

		if(empty($tags)) return $return;

		foreach($tags as $oneTag => $parameter){
			if(isset($this->tags[$oneTag])) continue;
			$allcats = explode('-', $parameter->id);
			$selectedArea = array();
			foreach($allcats as $oneCat){
				if(empty($oneCat)) continue;
				$selectedArea[] = intval($oneCat);
			}

			$query = 'SELECT DISTINCT a.id FROM #__iproperty AS a JOIN #__iproperty_propmid AS b ON a.id = b.prop_id LEFT JOIN #__iproperty_categories AS c ON b.cat_id = c.id ';

			$where = array();

			// load only needed content
			if(!empty($selectedArea)){
				$where[] = 'b.cat_id IN ('.implode(',', $selectedArea).')';
			}

			if(!empty($parameter->stype)){
				$where[] = 'a.stype = '.intval($parameter->stype);
			}

			// filter results created or modified
			if(!empty($parameter->filter) && !empty($email->params['lastgenerateddate'])){
				if($parameter->filter == 'created'){
					$where[] = 'a.created > \''.date('Y-m-d H:i:s', $email->params['lastgenerateddate'] - date('Z')).'\'';
				}elseif($parameter->filter == 'modified'){
					$where[] = 'a.created > \''.date('Y-m-d H:i:s', $email->params['lastgenerateddate'] - date('Z')).'\' OR a.modified > \''.date('Y-m-d H:i:s', $email->params['lastgenerateddate'] - date('Z')).'\'';
				}
			}

			// Only published content
			$where[] = "a.state = 1";

			if(!empty($parameter->featured)) $where[] = "a.featured = 1";
			if(!empty($parameter->nofeatured)) $where[] = "a.featured = 0";

			if(!empty($parameter->minprice)) $where[] = "a.price > ".intval($parameter->minprice);
			if(!empty($parameter->maxprice)) $where[] = "a.price < ".intval($parameter->maxprice);

			// Apply filters
			if(!empty($where)) $query .= ' WHERE ('.implode(') AND (', $where).')';

			// Ordering
			if(!empty($parameter->order)){
				$ordering = explode(',', $parameter->order);
				if($ordering[0] == 'rand'){
					$query .= ' ORDER BY rand()';
				}else{
					$query .= ' ORDER BY a.'.acymailing_secureField(trim($ordering[0])).' '.acymailing_secureField(trim($ordering[1]));
				}
			}

			$start = '';
			if(!empty($parameter->start)) $start = intval($parameter->start).',';

			// If there is no limit, then we add one
			if(!empty($parameter->max)){
				$query .= ' LIMIT '.$start.intval($parameter->max);
			}else{
				$query .= ' LIMIT '.$start.'20';
			} // limit, because we do not want to display one bilion contents in the newsletter...

			// load content IDs
			$allArticles = acymailing_loadResultArray($query);

			// Check the number of results
			if(!empty($parameter->min) && count($allArticles) < $parameter->min){
				//We will not generate the Newsletter
				$return->status = false;
				$return->message = 'Not enough '.$this->name.' content for the tag '.$oneTag.' : '.count($allArticles).' / '.$parameter->min;
			}

			$stringTag = '';
			if(!empty($allArticles)){
				// If the user created its own template...
				if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'auto'.$this->name.'.php')){
					ob_start();
					require(ACYMAILING_MEDIA.'plugins'.DS.'auto'.$this->name.'.php');
					$stringTag = ob_get_clean();
				}else{
					//we insert the tags one after the other in a table as they are already sorted (using |cols parameter)
					$arrayElements = array();
					foreach($allArticles as $oneArticleId){
						$args = array();
						$args[] = $this->name.':'.$oneArticleId;
						if(!empty($parameter->link)) $args[] = 'link';
						if(!empty($parameter->readmore)) $args[] = 'readmore';
						if(!empty($parameter->wrap)) $args[] = 'wrap:'.$parameter->wrap;
						if(!empty($parameter->display)) $args[] = 'display:'.$parameter->display;
						if(isset($parameter->pict)) $args[] = 'pict:'.$parameter->pict;
						if(!empty($parameter->maxwidth)) $args[] = 'maxwidth:'.$parameter->maxwidth;
						if(!empty($parameter->maxheight)) $args[] = 'maxheight:'.$parameter->maxheight;
						$arrayElements[] = '{'.implode('|', $args).'}';
					}
					$stringTag = $this->acypluginsHelper->getFormattedResult($arrayElements, $parameter);
				}
			}
			$this->tags[$oneTag] = $stringTag;
		}
		return $return;
	}
}