<?php
/**
 * @copyright    Copyright (C) 2009-2015 ACYBA SARL - All rights reserved..
 * @license        GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */
defined('_JEXEC') or die('Restricted access');

class plgAcymailingKunena extends JPlugin{
	/** Kunena version */
	var $kunenaVersion;
	/** Joomla application */
	var $app;

	function __construct(&$subject, $config){
		parent::__construct($subject, $config);

		//This is just to fix a bug with an old version of Joomla where the params were not loaded
		if(!isset($this->params)){
			$plugin = JPluginHelper::getPlugin('acymailing', 'kunena');
			$this->params = new acyParameter($plugin->params);
		}
	}

	//This function will enable you to display a new tab in the tag interface (when you click Newsletter->create->tags)
	//If you don't want an interface on the tag system, just remove this function, this is not mandatory
	function acymailing_getPluginType(){

		$config = acymailing_config();
		if(version_compare($config->get('version'), '5.6.1', '<')){
			acymailing_display('Please download and install the latest AcyMailing version otherwise this plugin will NOT work', 'error');
			return;
		}

		if($this->params->get('frontendaccess') == 'none' && !acymailing_isAdmin()) return;

		$onePlugin = new stdClass();
		$onePlugin->name = 'Kunena';
		$onePlugin->function = 'acymailingkunena_show';
		$onePlugin->help = 'plugin-kunena';

		return $onePlugin;
	}

	function _categories(){

		// Kunena >= 2.0
		if(class_exists('KunenaForum') && KunenaForum::installed() && (KunenaForum::isCompatible('2.0') || KunenaForum::isCompatible('5.0'))){
			$categories = acymailing_loadObjectList('SELECT id, name, parent_id AS parent
				 FROM #__kunena_categories
				 WHERE published=\'1\' ORDER BY ordering, name');
		}else // 1.6 <= Kunena < 2.0
		{
			$categories = acymailing_loadObjectList('SELECT id, name, parent
				 FROM #__kunena_categories
				 WHERE published=\'1\' ORDER BY ordering, name');
		}

		if(!is_array($categories)){
			acymailing_enqueueMessage(acymailing_getDBError(), 'error');
			return;
		}

		// Group categories by parent
		$this->cats = array();
		foreach($categories as $cat){
			$this->cats [$cat->parent] [] = $cat;
		}

		// Turn the list into a tree
		$this->catvalues = array();
		$this->_handleChildrens();

		return $this->catvalues;
	}

	function _handleChildrens($parent = 0, $level = 0){
		if(empty($this->cats[$parent])) return;
		foreach($this->cats[$parent] as $cat){
			//$cat->name = str_repeat($this->separator,$level).$cat->cat_name;
			$this->catvalues[] = array('id' => $cat->id, 'parent' => $cat->parent, 'name' => str_repeat(" - - ", $level).$cat->name);
			$this->_handleChildrens($cat->id, $level + 1);
		}
	}

	//This is the function name I specified in the previous $onePlugin->function argument.
	//This function will be triggered if my tab is selected on the interface
	function acymailingkunena_show(){
		if(!$this->_importDependencies()) return;

		// Set tabs
		$tabs = acymailing_get('helper.acytabs');

		// Tab 1 : Kunena messages
		echo $tabs->startPane('kunenacontent_tab');

		// Kunena < 2.0 ?
		$string = version_compare($this->kunenaVersion, '2.0', '<') ? 'COM_KUNENA_GEN_TOPICS' : 'COM_KUNENA_TRASH_TOPICS';

		$choice = array();
		$choice[] = acymailing_selectOption("1", acymailing_translation('JOOMEXT_YES'));
		$choice[] = acymailing_selectOption("0", acymailing_translation('JOOMEXT_NO'));

		echo $tabs->startPanel(acymailing_translation($string), 'kunenacontent_content');
		?>
		<br style="font-size:1px"/>
		<script language="javascript" type="text/javascript">
			<!--
			var selectedCategories = new Array();
			function applyAutoContent(catid, rowClass){
				if(catid == 'all'){
					if(window.document.getElementById('content_cat' + catid).className == 'selectedrow'){
						window.document.getElementById('content_catall').className = rowClass;
					}else{
						window.document.getElementById('content_cat' + catid).className = 'selectedrow';
						for(key in selectedCategories){
							if(!isNaN(key)){
								window.document.getElementById('content_cat' + key).className = rowClass;
								delete selectedCategories[key];
							}
						}
					}
				}else{
					window.document.getElementById('content_catall').className = 'row0';
					if(selectedCategories[catid]){
						window.document.getElementById('content_cat' + catid).className = rowClass;
						delete selectedCategories[catid];
					}else{
						window.document.getElementById('content_cat' + catid).className = 'selectedrow';
						selectedCategories[catid] = 'content';
					}
				}
				updateAutoTag();
			}

			function updateAutoTag(){
				tag = '{kunenacontent:';
				for(var icat in selectedCategories){
					if(selectedCategories[icat] == 'content'){
						tag += icat + '-';
					}
				}

				var tmp = 0;
				for(var i = 0; i < document.adminForm.cbdisplay.length; i++){
					if(document.adminForm.cbdisplay[i].checked){
						if(tmp == 0){
							tmp += 1;
							tag += "| fields:" + document.adminForm.cbdisplay[i].value;
						}else{
							tag += "," + document.adminForm.cbdisplay[i].value;
						}
					}
				}

				tag += '| display:' + (document.adminForm.displayposts.checked ? 'posts' : 'topics');
				tag += '| icon:';


				var imgsize = document.getElementById('imgsize');

				if(document.adminForm.icon0.checked){
					imgsize.setAttribute('style', 'display: none;');
					tag += 'noicon';
				}else{
					imgsize.setAttribute('style', 'display: table-row;');
					tag += document.adminForm.icontopicIcon.checked ? 'topicicon' : 'authoravatar';
					if(document.adminForm['imgwidth'] && document.adminForm['imgheight']){
						var width = parseInt(document.adminForm['imgwidth'].value)
						var height = parseInt(document.adminForm['imgheight'].value)
						if(!isNaN(width) && !isNaN(height)){
							tag += ',' + width + 'x' + height;
						}
					}
				}

				for(var i = 0; i < document.adminForm.readmore.length; i++){
					if(document.adminForm.readmore[i].checked && document.adminForm.readmore[i].value != '0'){
						tag += '| readmore';
					}
				}
				<?php if(version_compare($this->kunenaVersion, '2.0', '>=')){ ?>
				if(document.adminForm.displayposts.checked){
					document.getElementById('kunenaorderlabel').style.display = '';
					document.getElementById('kunenaorder').style.display = '';
					if(document.adminForm.contentorder.value != "0"){
						tag += "| order:" + document.adminForm.contentorder.value;
					}
				}else{
					document.getElementById('kunenaorderlabel').style.display = 'none';
					document.getElementById('kunenaorder').style.display = 'none';
				}
				<?php } ?>

				if(document.adminForm.pCount1.checked){
					tag += '| pcount'
				}
				if(document.adminForm.authorName1.checked){
					tag += '| authorname'
				}
				<?php if (acymailing_getVar('string', 'type') === 'autonews') { ?>
				if(document.adminForm.minElts.value && parseInt(document.adminForm.minElts.value) != NaN){
					tag += '| min:' + document.adminForm.minElts.value;
				}
				<?php }	?>
				if(document.adminForm.maxElts.value && parseInt(document.adminForm.maxElts.value) != NaN){
					tag += '| max:' + document.adminForm.maxElts.value;
				}
				if(document.adminForm.timeLimit.value && parseInt(document.adminForm.timeLimit.value) != NaN){
					tag += '| timelimit:' + document.adminForm.timeLimit.value;
				}
				tag += '}';
				setTag(tag);
			}
			//-->
		</script>
		<?php
		$ordering = array();
		$ordering[] = acymailing_selectOption("0", acymailing_translation('FIELD_DEFAULT'));
		$ordering[] = acymailing_selectOption("m.id DESC", acymailing_translation('ACY_ID'));
		$ordering[] = acymailing_selectOption("m.time DESC", acymailing_translation('CREATED_DATE'));
		$ordering[] = acymailing_selectOption("m.modified_time DESC", acymailing_translation('MODIFIED_DATE'));
		$ordering[] = acymailing_selectOption("m.subject ASC", acymailing_translation('FIELD_TITLE'));
		$ordering[] = acymailing_selectOption("m.thread DESC, m.id ASC", 'Group by topic');

		$fieldsDisplay = array();
		$fieldsDisplay[] = array('title' => 'title', 'label' => 'ACY_TITLE', 'checked' => 'yes');
		$fieldsDisplay[] = array('title' => 'content', 'label' => 'ACY_DESCRIPTION', 'checked' => 'yes');
		$fieldsDisplay[] = array('title' => 'date', 'label' => 'CREATED_DATE', 'checked' => 'yes');
		?>
		<div class="onelineblockoptions">
			<table width="100%" class="acymailing_table">
				<tr>
					<td nowrap="nowrap"><?php echo acymailing_translation('DISPLAY');?></td>
					<?php
					$i = 1;
					foreach($fieldsDisplay as $oneField){
						if($i == 4){
							echo '</tr><tr><td/>';
							$i = 1;
						}
						echo '<td nowrap="nowrap"><input type="checkbox" name="cbdisplay" value="'.$oneField['title'].'" id="'.$oneField['title'].'" '.(($oneField['checked'] == 'yes') ? 'checked' : '').' onclick="updateAutoTag();"/><label style="margin-left:5px" for="'.$oneField['title'].'">'.trim(acymailing_translation($oneField['label']), ':').'</label></td>';
						$i++;
					}
					while($i != 4){
						echo '<td/>';
						$i++;
					}
					?>
				</tr>
				<tr>
					<td>
						<?php echo acymailing_translation('ACY_TYPE'); ?>
					</td>
					<td>
						<?php

						// Kunena < 2.0 ?
						$posts_title = version_compare($this->kunenaVersion, '2.0', '<') ? 'COM_KUNENA_GEN_MESSAGE' : 'COM_KUNENA_TRASH_MESSAGES';
						$topics_title = version_compare($this->kunenaVersion, '2.0', '<') ? 'COM_KUNENA_GEN_TOPICS' : 'COM_KUNENA_TRASH_TOPICS';

						$options = array(acymailing_selectOption('posts', acymailing_translation($posts_title)), acymailing_selectOption('topics', acymailing_translation($topics_title)));
						echo acymailing_radio($options, 'display', 'onchange="updateAutoTag();"', 'value', 'text', 'posts');
						?>
					</td>
					<td nowrap="nowrap"><?php echo acymailing_translation('JOOMEXT_READ_MORE'); ?></td>
					<td nowrap="nowrap"><?php echo acymailing_radio($choice, 'readmore', 'size="1" onclick="updateAutoTag();"', 'value', 'text', '0'); ?></td>
				</tr>
				<tr>
					<td>
						<?php echo acymailing_translation('DISPLAY_PICTURES'); ?>
					</td>
					<td colspan="3">
						<?php
						$options = array(acymailing_selectOption('authorAvatar', acymailing_translation('COM_KUNENA_USRL_AVATAR')), acymailing_selectOption('topicIcon', acymailing_translation('COM_KUNENA_GEN_TOPIC_ICON')), acymailing_selectOption('0', ucfirst(acymailing_translation('ACY_NONE'))));
						echo acymailing_radio($options, 'icon', 'onchange="updateAutoTag();"', 'value', 'text', 'authorAvatar'); ?>
					</td>
				</tr>
				<tr id="imgsize">
					<td>
						<?php
						if(!ACYMAILING_J16){
							echo acymailing_translation('FIELD_SIZE');
						}else{
							echo acymailing_translation('COM_MEDIA_MAXIMUM_SIZE');
						}
						?>
					</td>
					<td colspan="3">
						<?php echo acymailing_translation('CAPTCHA_WIDTH') ?>
						<input name="imgwidth" type="text" onchange="updateAutoTag();" value="100" size="1" style="width:50px;"/>px
						× <?php echo acymailing_translation('CAPTCHA_HEIGHT') ?>
						<input name="imgheight" type="text" onchange="updateAutoTag();" value="100" size="1" style="width:50px;"/>px
					</td>
				</tr>
				<tr>
					<td>
						<?php echo acymailing_translation('COM_KUNENA_STAT_TOTAL_MESSAGES'); ?>
					</td>

					<td>
						<?php echo acymailing_boolean('pCount', 'onchange="updateAutoTag();"', false); ?>
					</td>
					<td>
						<?php echo acymailing_translation('AUTHOR_NAME'); ?>
					</td>
					<td>
						<?php echo acymailing_boolean('authorName', 'onchange="updateAutoTag();"', false); ?>
					</td>

				</tr>
				<tr>
					<td>
						<?php echo acymailing_translation('MAX_ARTICLE'); ?>
					</td>
					<td>
						<input type="text" size="1" name="maxElts" value="5" onchange="updateAutoTag();" style="width:50px;"/>
					</td>
					<td>

						<?php echo acymailing_translation('CREATED_DATE'); ?>
					</td>
					<td>
						<input type="text" size="2" name="timeLimit" value="24" onchange="updateAutoTag();" style="width:50px;"/>
						<?php echo strtolower(acymailing_translation('HOURS')); ?>
					</td>
				</tr>
				<?php if(acymailing_getVar('string', 'type') === 'autonews'){ ?>
					<tr>
						<td>
							<?php echo acymailing_translation('MIN_ARTICLE'); ?>
						</td>
						<td<?php if(version_compare($this->kunenaVersion, '2.0', '<')){
							echo ' colspan="3"';
						} ?>>
							<input type="text" size="1" name="minElts" value="0" onchange="updateAutoTag();" style="width:50px;"/>
						</td>
						<?php if(version_compare($this->kunenaVersion, '2.0', '>=')){ ?>
							<td nowrap="nowrap">
								<div id="kunenaorderlabel"><?php echo acymailing_translation('ACY_ORDER'); ?></div>
							</td>
							<td nowrap="nowrap">
								<div id="kunenaorder"><?php echo acymailing_select($ordering, 'contentorder', 'size="1" onchange="updateAutoTag();" style="width:200px;"', 'value', 'text'); ?></div>
							</td>
						<?php } ?>
					</tr>
				<?php }elseif(version_compare($this->kunenaVersion, '2.0', '>=')){ ?>
					<tr>
						<td nowrap="nowrap">
							<div id="kunenaorderlabel"><?php echo acymailing_translation('ACY_ORDER'); ?></div>
						</td>
						<td nowrap="nowrap" colspan="3">
							<div id="kunenaorder"><?php echo acymailing_select($ordering, 'contentorder', 'size="1" onchange="updateAutoTag();" style="width:200px;"', 'value', 'text'); ?></div>
						</td>
					</tr>
				<?php } ?>
			</table>
		</div>

		<div class="onelineblockoptions">
			<table class="acymailing_table" cellpadding="1" width="100%">
				<thead>
				<tr>
					<th class="title">
					</th>
					<th class="title">
						<?php echo acymailing_translation('TAG_CATEGORIES'); ?>
					</th>
				</tr>
				</thead>
				<tbody>
				<tr id="content_catall" class="<?php echo "row0"; ?>" onclick="applyAutoContent('all','<?php echo "row0" ?>');" style="cursor:pointer;">
					<td class="acytdcheckbox"></td>
					<td><?php echo acymailing_translation('ACY_ALL'); ?></td>
				</tr>
				<?php
				$k = 1;
				$cats = $this->_categories();
				foreach($cats as $index => $cat){
					?>
					<tr id="content_cat<?php echo $cat['id'] ?>" class="<?php echo "row$k"; ?>" onclick="applyAutoContent(<?php echo $cat['id'] ?>,'<?php echo "row$k" ?>');" style="cursor:pointer;">
						<td class="acytdcheckbox"></td>
						<td>

							<?php
							echo $cat['name'];
							?>
						</td>
					</tr>
					<?php
					$k = 1 - $k;
				}
				?>
				</tbody>
			</table>
		</div>
		<?php
		echo $tabs->endPanel();

		// Tab 2 : Kunena users
		echo $tabs->startPanel(acymailing_translation('COM_KUNENA_PROFILE_EDIT_PROFILE'), 'kunenacontent_auto');
		?>
		<br style="font-size:1px"/>
		<script language="javascript" type="text/javascript"></script>
		<?php
		$notallowed = array('userid', 'view', 'moderator', 'banned', 'ordering', 'karma_time', 'group_id', 'uhits', 'hideemail', 'showonline');
		$text = '<div class="onelineblockoptions"><table class="acymailing_table" cellpadding="1">';
		$fields = acymailing_getColumns('#__kunena_users');
		$k = 0;

		foreach($fields as $fieldname => $oneField){

			if(in_array(strtolower($fieldname), $notallowed)) continue;

			$name = acymailing_translation('COM_KUNENA_MYPROFILE_'.strtoupper($fieldname));
			$desc = acymailing_translation('COM_KUNENA_MYPROFILE_'.strtoupper($fieldname).'_DESC');

			if(strtoupper($name) === $name){
				//$name = $fieldname;
				switch($fieldname){
					case 'status':
						$name = acymailing_translation('STATUS');
						break;
					case 'status_text':
						$name = acymailing_translation('COM_KUNENA_STATUS');
						break;
					case 'avatar':
						$name = acymailing_translation('COM_KUNENA_USRL_AVATAR');
						break;
					case 'karma':
						$name = acymailing_translation('COM_KUNENA_KARMA');
						break;
					case 'websitename':
						$name = acymailing_translation('COM_KUNENA_MYPROFILE_WEBSITE_NAME');
						$desc = acymailing_translation('COM_KUNENA_MYPROFILE_WEBSITE_NAME_DESC');
						break;
					case 'websiteurl':
						$name = acymailing_translation('COM_KUNENA_MYPROFILE_WEBSITE_URL');
						$desc = acymailing_translation('COM_KUNENA_MYPROFILE_WEBSITE_URL_DESC');
						break;
					case 'thankyou':
						$name = acymailing_translation('COM_KUNENA_VIEW_TOPICS_POSTS_MODE_THANKYOU');
					case 'canSubscribe':
						$name = acymailing_translation('COM_KUNENA_USER_CANSUBSCRIBE');
						break;
					case 'userListtime':
						$name = acymailing_translation('COM_KUNENA_USER_USERLISTTIME');
						break;
					case 'ip':
						$name = acymailing_translation('IP');
						break;
				}
			}
			if(strtoupper($desc) === $desc) $desc = '';

			switch($fieldname){
				case 'avatar':
					$type = '|type:image';
					break;
				case 'birthdate':
					$type = '|type:date';
					break;
				default:
					$type = '';
			}

			$text .= '<tr style="cursor:pointer" class="row'.$k.'" onclick="setTag(\'{kunenauser:'.$fieldname.$type.'}\');insertTag();" >';
			$text .= '<td>'.$name.'</td><td>'.$desc.'</td></tr>';
			$k = 1 - $k;
		}
		$text .= '</table></div>';
		echo $text;

		echo $tabs->endPanel();
		echo $tabs->endPane();
	}

	//This function will be triggered on the preview screen and during the send process to replace personal global tags
	//Any tag which is not user specific should be replaced by this function in order to optimize the process
	function acymailing_replacetags(&$email, $send = true){

		$this->acymailing_generateautonews($email);

		if(!empty($this->tags)){
			$email->body = str_replace(array_keys($this->tags), $this->tags, $email->body);
			$this->mailerHelper = acymailing_get('helper.mailer');
			$textTags = array();
			$subjectTags = array();

			foreach($this->tags as $tag => $result){
				//$subjectTags[$tag] = str_replace($tag, strip_tags(str_replace('</tr><tr>', ' | ', $result)));
				$subjectTags[$tag] = strip_tags(str_replace('</tr><tr>', ' | ', $result));
				$textTags[$tag] = $this->mailerHelper->textVersion($result);
			}

			if(!empty ($email->altbody)) $email->altbody = str_replace(array_keys($textTags), $textTags, $email->altbody);
			$email->subject = str_replace(array_keys($subjectTags), $subjectTags, $email->subject);
		}
	}

	function acymailing_generateautonews(&$email){
		$return = new stdClass();
		$return->status = true;
		$return->message = '';

		//Check if we should generate the SmartNewsletter or not...
		$match = '#{kunenacontent:(.*)}#Ui';
		$variables = array('subject', 'body', 'altbody');
		$found = false;
		$results = array();
		foreach($variables as $var){
			if(empty ($email->$var)){
				continue;
			}
			$found = preg_match_all($match, $email->$var, $results[$var]) || $found;
			//we unset the results so that we won't handle it later... it will save some memory and processing
			if(empty ($results[$var][0])){
				unset ($results[$var]);
			}
		}

		//If we didn't find anything... so we won't try to stop the generation
		if(!$found) return $return;

		$this->readmore = empty($email->template->readmore) ? acymailing_translation('JOOMEXT_READ_MORE') : '<img src="'.ACYMAILING_LIVE.$email->template->readmore.'" alt="'.acymailing_translation('JOOMEXT_READ_MORE', true).'" />';

		$this->tags = array();

		foreach($results as $var => $allresults){
			foreach($allresults[0] as $i => $oneTag){
				if(isset ($this->tags[$oneTag])) continue;

				$ret = $this->_replaceContent($allresults, $i);
				if(is_object($ret) && isset($ret->status) && !$ret->status){
					$return->status = false;
					$return->message .= !empty($ret->message) ? $ret->message.' ' : '';
				}
			}
		}

		return $return;
	}

	//This function will be triggered during the send process to replace personal tags (user specific information)
	//If you don't want to replace personal tags (specific to the user), then you can delete this function
	function acymailing_replaceusertags(&$email, &$user, $send = true){

		$match = '#(?:{|%7B)kunenauser:(.*)(?:}|%7D)#Ui';
		$variables = array('subject', 'body', 'altbody');
		$found = false;
		$results = array();

		foreach($variables as $var){
			if(empty($email->$var)) continue;
			$found = preg_match_all($match, $email->$var, $results[$var]) || $found;
			if(empty($results[$var][0])) unset($results[$var]);
		}
		if(!$found) return;

		$values = new stdClass();
		if(!empty($user->userid)){
			$values = acymailing_loadObject('SELECT * FROM '.acymailing_table('kunena_users', false).' WHERE userid = '.intval($user->userid).' LIMIT 1');
		}

		if(!$this->_importDependencies()) return;

		$tags = array();
		foreach($results as $var => $allresults){
			foreach($allresults[0] as $i => $oneTag){
				if(isset($tags[$oneTag])) continue;
				$arguments = explode('|', $allresults[1][$i]);
				$field = $arguments[0];
				unset($arguments[0]);
				$mytag = new stdClass();
				$mytag->default = $this->params->get('default_'.$field, '');
				if(!empty($arguments)){
					foreach($arguments as $onearg){
						$args = explode(':', $onearg);
						if(isset($args[1])){
							$mytag->{$args[0]} = $args[1];
						}else{
							$mytag->{$args[0]} = 1;
						}
					}
				}
				$replaceme = isset($values->$field) ? $values->$field : $mytag->default;

				switch($field){
					case 'avatar':
						// Loads the avatar of the user
						$kuser = KunenaUser::getInstance($user->userid);
						$replaceme = $kuser->getAvatarURL();
						if(!empty($mytag->type) && $mytag->type == 'image'){
							$replaceme = '<img src="'.$replaceme.'" alt="" />';
						}
						break;
					case 'birthdate':
						if(!empty($mytag->type) && $mytag->type == 'date' && strpos($replaceme, '-')){
							$tmp = explode('-', $replaceme);
							$replaceme = mktime(12, 0, 0, $tmp[1], $tmp[2], $tmp[0]);
							if(empty($mytag->format)) $mytag->format = acymailing_translation('DATE_FORMAT_LC3');
							$replaceme = acymailing_getDate($replaceme, $mytag->format);
							unset($mytag->type);
						}
						break;
					case 'gender':
						if($replaceme === '1') $replaceme = acymailing_translation('COM_KUNENA_MYPROFILE_GENDER_MALE');
						elseif($replaceme === '2') $replaceme = acymailing_translation('COM_KUNENA_MYPROFILE_GENDER_FEMALE');
						else $replaceme = acymailing_translation('COM_KUNENA_MYPROFILE_GENDER_UNKNOWN');
						break;
					case 'location':
						$replaceme = '<a href="https://maps.google.com?q='.urlencode(strtr($replaceme, '"', '')).'">'.$replaceme.'</a>';
						break;
					case 'signature':
						// Kunena >= 2.0
						if(!version_compare($this->kunenaVersion, '2.0', '<')){
							$replaceme = KunenaHtmlParser::parseText($replaceme);
							$replaceme = KunenaHtmlParser::parseBBCode($replaceme);
						}else // 1.6 <= Kunena < 2.0
						{
							$replaceme = KunenaParser::parseText($replaceme);
							$replaceme = KunenaParser::parseBBCode($replaceme);
						}
						break;
					default:
				}

				if(!empty($mytag->type)){
					if($mytag->type == 'date'){
						if(empty($mytag->format)) $mytag->format = acymailing_translation('DATE_FORMAT_LC3');
						$replaceme = acymailing_getDate(acymailing_getTime($replaceme), $mytag->format);
					}
				}
				if(!empty($mytag->lower)) $replaceme = strtolower($replaceme);
				if(!empty($mytag->ucwords)) $replaceme = ucwords($replaceme);
				if(!empty($mytag->ucfirst)) $replaceme = ucfirst($replaceme);
				if(!empty($mytag->urlencode)) $replaceme = urlencode($replaceme);

				$tags[$oneTag] = $replaceme;
			}
		}

		foreach($results as $var => $allresults){
			$email->$var = str_replace(array_keys($tags), $tags, $email->$var);
		}
	}

	function _getSubCats($categories){
		foreach($categories as $oneCat){
			if(is_object($oneCat)) $oneCat = $oneCat->id;
			$this->subcats[] = $oneCat;
			if(!empty($this->cats[$oneCat])){
				$this->_getSubCats($this->cats[$oneCat]);
			}
		}
	}

	/**
	 * Replace Kunena messages
	 */
	function _replaceContent(&$results, $i){

		$this->acypluginsHelper = acymailing_get('helper.acyplugins');
		$return = new stdClass();
		$return->status = true;
		$return->message = '';
		$this->tag = $this->acypluginsHelper->extractTag($results[1][$i]);
		$this->tag->id = trim(preg_replace('/[^0-9]/', ',', $this->tag->id), ',');
		if(!preg_match('/[0-9]/', $this->tag->id)) $this->tag->id = '0';
		if(!empty($this->tag->fields)){
			$fields = explode(',', $this->tag->fields);
			$this->tag->extractedfields = array();
			foreach($fields as $oneField){
				$this->tag->extractedfields[$oneField] = true;
			}
		}
		$this->tag->display = (!empty($this->tag->display) && $this->tag->display == 'topics') ? 'topics' : 'posts';

		$this->tag->iconwidth = 9999;
		$this->tag->iconheight = 9999;
		if(!empty($this->tag->icon)){
			if(strpos($this->tag->icon, ',')){
				$icon = explode(',', $this->tag->icon);
				$this->tag->icon = $icon[0];
				if(strpos($icon[1], 'x')){
					$iconsize = explode('x', $icon[1]);
					$this->tag->iconwidth = max(intval($iconsize[0]), 1);
					$this->tag->iconheight = max(intval($iconsize[1]), 1);
				}
			}
		}
		$this->tag->icon = (!empty($this->tag->icon) && in_array($this->tag->icon, array('topicicon', 'noicon'))) ? $this->tag->icon : 'authoravatar';
		$this->tag->pcount = !empty($this->tag->pcount);
		$this->tag->authorname = !empty($this->tag->authorname);
		$this->tag->max = empty($this->tag->max) ? 5 : max(min(intval($this->tag->max), 100), 1);
		$this->tag->timelimit = !empty($this->tag->timelimit) ? intval($this->tag->timelimit) : 0;

		// Imports dependencies
		if(!$this->_importDependencies()){
			$return->status = false;
			return $return;
		}

		// Gets latest elements

		$messages = array();

		// Kunena >= 2.0
		if(version_compare($this->kunenaVersion, '2.0', '>=')){
			$categories = !empty($this->tag->id) ? explode(',', $this->tag->id) : false;

			if(!empty($categories) && !empty($this->tag->subcats)){
				$this->_categories();
				$this->subcats = array();
				$this->_getSubCats($categories);
				$categories = $this->subcats;
			}

			$limitStart = 0;
			$limit = $this->tag->max;
			$params = array('starttime' => !empty($this->tag->timelimit) ? time() - $this->tag->timelimit * 3600 : 0);

			if($this->tag->display == 'posts' && !empty($this->tag->order) && in_array($this->tag->order, array("m.id DESC", "m.time DESC", "m.modified_time DESC", "m.subject ASC", "m.thread DESC, m.id ASC"))){
				$params['orderby'] = $this->tag->order;
			}

			if($this->tag->display == 'topics'){
				$messages = KunenaForumTopicHelper::getLatestTopics($categories, $limitStart, $limit, $params);
			}else{
				$messages = KunenaForumMessageHelper::getLatestMessages($categories, $limitStart, $limit, $params);
			}

			if(!empty($messages[1])){
				// In Kunena 2.0+, the first item is an integer, the second an array
				$messages = $messages[1];
			}
		}else // 1.6 <= Kunena < 2.0
		{
			// Initializes Kunena
			acymailing_setVar('sel', $this->tag->timelimit);
			KunenaFactory::getSession(true);

			$model = new CKunenaLatestX('', 0);
			$model->threads_per_page = $this->tag->max;
			$model->latestcategory = explode(',', $this->tag->id);
			$model->latestcategory_in = empty($model->latestcategory) ? 0 : 1;
			//TODO : find a way to add an order option

			if($this->tag->display == 'topics'){
				$model->getLatest();
			}else{
				$model->getLatestPosts();
			}
			$messages = $model->messages;

			// Sort the messages by topic, then by created date if topictitle option is added
			if($this->tag->display == 'posts' && !empty($this->tag->topictitle)){
				$sortedMessages = array();
				foreach($messages as $oneMessage){
					$sortedMessages[$oneMessage->thread][] = $oneMessage;
				}

				$messages = array();
				foreach($sortedMessages as &$oneMessagethread){
					usort($oneMessagethread, function ($a, $b){
						return strcmp($a->id, $b->id);
					});
					$messages = array_merge($messages, $oneMessagethread);
				}
			}
		}

		$messagesCount = 0;

		// Output content
		$articles = '<div class="acymailing_content"><table class="acykunena" cellspacing="0" cellpadding="0" border="0" style="width:100%;">';


		$pictureHelper = acymailing_get('helper.acypict');
		$this->currenttopicid = -1;

		$customArticle = '';

		foreach($messages as $key => $msg){
			$article = '';
			if(!is_object($msg)) continue;
			$varFields = array();

			// Show first post, not latest
			if($this->tag->display == 'topics'){
				if(!empty($msg->parent)) continue;

				// Too old ? skip it !
				if($this->tag->timelimit > 0){
					$limit = time() - $this->tag->timelimit * 3600 + 1800; //move 30 minutes back to compensate for expired sessions

					// Topic or post?
					$time = isset($msg->first_post_time) ? $msg->first_post_time : $msg->time;

					if($time < $limit) continue;
				}
			}else{
				if($this->tag->timelimit > 0){
					$limit = time() - $this->tag->timelimit * 3600 + 1800; //move 30 minutes back to compensate for expired sessions
					if($msg->time < $limit && (empty($msg->modified_time) || $msg->modified_time < $limit)) continue;
				}
			}
			// Count the number of posts in the topic
			$count = '';
			if($this->tag->pcount && !empty($msg->thread)){
				$query = 'SELECT COUNT(*) AS c FROM #__kunena_messages WHERE thread='.intval($msg->thread);
				$count = acymailing_loadObjectList($query);
				if(!is_array($count)){
					acymailing_enqueueMessage(acymailing_getDBError(), 'error');
					return;
				}
				$count = '<span style="font-weight: normal; font-size: 85%;" title="'.acymailing_translation('COM_KUNENA_STAT_TOTAL_MESSAGES').'"> ('.$count[0]->c.')</span>';
			}

			// Kunena >= 2.0
			if(!version_compare($this->kunenaVersion, '2.0', '<')){
				// Topic or post?
				$msg->message = isset($msg->first_post_message) ? $msg->first_post_message : $msg->message;
				if(strpos($msg->message, '[spoiler]') !== false) $msg->message = preg_replace('#\[spoiler\]([^\[]*)\[/spoiler\]#i', '$1', $msg->message);
				if(strpos($msg->message, '[url') !== false) $msg->message = preg_replace('#\[url=([^\]]*)\]([^\[]*)\[/url\]#i', '<a href="$1">$2</a>', $msg->message);
				if(strpos($msg->message, '[video]') !== false){
					$msg->message = preg_replace('#\[video\][^\[]*youtube[^\[]*v=([^\[]*)\[/video\]#i', '<a href="http://www.youtube.com/watch?v=$1"><img src="http://img.youtube.com/vi/$1/0.jpg"/></a>', $msg->message);
					$msg->message = preg_replace('#\[video\]([^\[]*)\[/video\]#i', '<a href="$1"><img src="media/com_acymailing/images/video.png"/></a>', $msg->message);
				}
				if(strpos($msg->message, '[article]') !== false) $msg->message = preg_replace('#\[article\]([^\[]*)\[/article\]#i', '', $msg->message);


				if($msg->get("_table") == "KunenaTopics"){
					$id = acymailing_loadResult('SELECT id FROM #__kunena_messages WHERE thread = '.$msg->id.' AND parent = 0');
				}else{
					$id = $msg->id;
				}

				$attachments = acymailing_loadObjectList('SELECT id, folder, filename FROM #__kunena_attachments WHERE mesid = '.intval($id).' AND filetype LIKE "image%"');
				if(!empty($attachments)){
					foreach($attachments as $oneAttachment){
						$msg->message = str_replace('[attachment='.$oneAttachment->id.']'.$oneAttachment->filename.'[/attachment]', '<img src="'.$oneAttachment->folder.'/'.$oneAttachment->filename.'"/>', $msg->message);
					}
				}

				$msg->message = preg_replace('#\[(code|ebay|map|attachment)[^\]]*\]([^\[]*)\[/(code|ebay|map|attachment)\]#i', '', $msg->message);
				$msg->message = KunenaHtmlParser::parseText($msg->message);
				$msg->message = KunenaHtmlParser::parseBBCode($msg->message, null, (int)$this->params->get('messagelength'));
				$msg->url = $msg->getUrl();
				$msg->message = str_replace('&amp;', '&', $msg->message);
				$msg->message = str_replace('&#8203;', '', $msg->message);
				$msg->message = htmlspecialchars_decode($msg->message, ENT_COMPAT);
				if(strlen($msg->message) > 3 && substr($msg->message, strlen($msg->message) - 3) == '...' && $this->params->get('readmore') == 'yes') $msg->message .= '<a style="text-decoration:none;" target="_blank" href="'.$msg->url.'"><span class="acymailing_readmore">'.$this->readmore.'</span></a>';
			}else // 1.6 <= Kunena < 2.0
			{
				$msg->message = KunenaParser::parseText($msg->message);
				$msg->message = KunenaParser::parseBBCode($msg->message, null, (int)$this->params->get('messagelength'));
				$msg->url = str_replace('/administrator/', '/', (string)CKunenaLink::getMessageURL($msg->id));
				if(strlen($msg->message) > 3 && substr($msg->message, strlen($msg->message) - 3) == '...' && $this->params->get('readmore') == 'yes') $msg->message .= '<a style="text-decoration:none;" target="_blank" href="'.$msg->url.'"><span class="acymailing_readmore">'.$this->readmore.'</span></a>';
			}

			$msg->icon = '';

			if($this->tag->icon == 'topicicon' && !empty($msg->topic_emoticon)){
				$tpl = KunenaTemplate::getInstance();
				$msg->icon = $tpl->getTopicIconPath($msg->topic_emoticon, true);
			}elseif($this->tag->icon == 'authoravatar'){

				// Topic or post?
				$userId = isset($msg->first_post_userid) ? $msg->first_post_userid : $msg->userid;

				$user = new KunenaUser($userId);
				$msg->icon = $user->getAvatarURL();
			}

			$msg->icon = empty($msg->icon) ? '' : '<img src="'.$msg->icon.'" class="icon" alt="" style="display: block; float: left;" />';

			// Resize icon
			$pictureHelper->maxHeight = $this->tag->iconheight;
			$pictureHelper->maxWidth = $this->tag->iconwidth;
			if($pictureHelper->available()) $msg->icon = $pictureHelper->resizePictures($msg->icon);
			$menu = $this->params->get('itemid');
			if(!empty($menu)){
				// The reference number must be at the end of the URL
				$number = strpos($msg->url, '#');
				if(empty($number)){
					$msg->url .= (strpos($msg->url, '?') ? '&' : '?').'Itemid='.$menu;
				}else{
					$URL = substr($msg->url, 0, $number);
					$msg->url = $URL.(strpos($URL, '?') ? '&' : '?').'Itemid='.$menu.substr($msg->url, $number);
				}
			}
			if($this->tag->display == 'posts' && strpos($msg->url, '#') == false){
				$msg->url .= '#'.$msg->id;
			}
			$article .= '<tr><td>';

			// Add the topic title
			if($this->tag->display == 'posts' && !empty($this->tag->topictitle) && $this->currenttopicid != $msg->thread){
				$this->currenttopicid = $msg->thread;
				if($msg->parent == 0){
					$msg->topictitle = $msg->subject;
				}else{
					if(version_compare($this->kunenaVersion, '2.0', '<')){
						$msg->topictitle = acymailing_loadResult('SELECT subject FROM #__kunena_messages WHERE thread = '.intval($msg->thread).' AND parent = 0 LIMIT 1');
					}else{
						$msg->topictitle = $msg->get('_topic')->subject;
					}
				}
				$article .= '<h3 class="topictitle"><a href="'.substr($msg->url, 0, strpos($msg->url, '#')).'">'.(empty($this->tag->topicprefix) ? '' : $this->tag->topicprefix).$msg->topictitle.'</a></h3>';
				if(!empty($this->tag->cattitle)){
					if(version_compare($this->kunenaVersion, '2.0', '>=')){
						$msg->catname = acymailing_loadResult('SELECT name FROM #__kunena_categories WHERE id = '.intval($msg->catid));
					}
					$article .= '<h4 class="cattitle"><a href="index.php?option=com_kunena&func=showcat&catid='.$msg->catid.'">'.(empty($this->tag->catprefix) ? '' : $this->tag->catprefix).$msg->catname.'</a></h4>';
				}
			}

			if(empty($this->tag->fields) || !empty($this->tag->extractedfields['title'])){
				if(count($this->tag->extractedfields) > 1) $article .= '<h2 class="acymailing_title">';
				$article .= '<a class="subject" href="'.$msg->url.'" title="'.addslashes($msg->subject).'">';
			}

			// Kunena >= 2.0
			if(version_compare($this->kunenaVersion, '2.0', '>=')){
				if(empty($this->tag->fields) || !empty($this->tag->extractedfields['title'])){
					$article .= KunenaHtmlParser::parseText($msg->subject, (int)$this->params->get('subjectlength'));
					if(count($this->tag->extractedfields) != 1){
						$article .= '</a>'.$count.'</h2>';
					}else $article .= $count.'</a>';
				}

				$article .= '<div class="wrapper">'.$msg->icon;
				if($this->tag->authorname && !empty($msg->name)) $article .= '<span class="authorname">'.acymailing_translation('COM_KUNENA_BY').' '.$msg->name.' </span>';

				// Topic or post?
				$time = isset($msg->first_post_time) ? $msg->first_post_time : $msg->time;

				$date = KunenaDate::getInstance($time);

				if(empty($this->tag->fields) || !empty($this->tag->extractedfields['date'])){
					$varFields['{createddate}'] = (empty($this->tag->dateprefix) ? '' : $this->tag->dateprefix).$date->toKunena();
					$article .= '<span class="createddate">'.$varFields['{createddate}'].'</span>';
				}
				$article .= '</div>';
			}else  // 1.6 <= Kunena < 2.0
			{
				if(empty($this->tag->fields) || !empty($this->tag->extractedfields['title'])){
					$article .= KunenaParser::parseText($msg->subject, (int)$this->params->get('subjectlength')).'</a>'.$count.'</h2>';
					if(count($this->tag->extractedfields) != 1){
						$article .= '</a>'.$count.'</h2>';
					}else $article .= $count.'</a>';
				}
				$article .= '<div class="wrapper">'.$msg->icon;
				if($this->tag->authorname) $article .= '<span class="authorname">'.acymailing_translation('COM_KUNENA_BY').' '.$msg->name.' </span>';
				if(empty($this->tag->fields) || !empty($this->tag->extractedfields['date'])){
					$varFields['{createddate}'] = (empty($this->tag->dateprefix) ? '' : $this->tag->dateprefix).CKunenaTimeformat::showDate($msg->time);
					$article .= '<span class="createddate">'.$varFields['{createddate}'].'</span>';
				}
				$article .= '</div>';
			}


			if(empty($this->tag->fields) || !empty($this->tag->extractedfields['content'])) $article .= '<div class="content">'.$msg->message.'</div>';
			if(!empty($this->tag->readmore)) $article .= '<a style="text-decoration:none;" target="_blank" href="'.$msg->url.'"><span class="acymailing_readmore">'.$this->readmore.'</span></a>';
			$article .= '</td></tr>';

			if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'kunenamessage.php')){
				foreach($msg as $fieldName => $oneField){
					if(is_object($oneField) || is_array($oneField)) continue;
					$varFields['{'.$fieldName.'}'] = $oneField;
				}
				ob_start();
				require(ACYMAILING_MEDIA.'plugins'.DS.'kunenamessage.php');
				$thisMessage = ob_get_clean();
				$article = str_replace(array_keys($varFields), $varFields, $thisMessage);
			}
			$articles .= $article;

			$messagesCount++;
		}

		$articles .= '</table></div>';


		// Is there enough messages to generate the newsletter?
		$minMessages = !empty($this->tag->min) ? intval($this->tag->min) : 0;
		$minMessages = max($minMessages, 0);

		if($messagesCount < $minMessages){
			// Not enough messages, we will not generate the Newsletter
			$this->tags[$results[0][$i]] = '';
			$return->status = false;
			$return->message = 'Not enough elements for the tag '.strip_tags($results[0][$i]).' : '.$messagesCount.' / '.$minMessages.'. Are your Kunena categories only accessible for logged-in users? If so you MUST take a look at the plugin\'s documentation, we give you here a workaround!';
			return $return;
		}

		if(file_exists(ACYMAILING_MEDIA.'plugins'.DS.'kunena.php')){
			ob_start();
			require(ACYMAILING_MEDIA.'plugins'.DS.'kunena.php');
			$articles = ob_get_clean();
		}

		$this->tags[$results[0][$i]] = &$articles;

		return $return;
	}

	/**
	 * Loads dependencies
	 * @return boolean
	 */
	function _importDependencies(){
		// Already imported?
		if(!empty($this->kunenaVersion)) return true;

		$this->app = JFactory::getApplication();

		// Kunena 2.0 API path
		$api = JPATH_ADMINISTRATOR.DS.'components'.DS.'com_kunena'.DS.'api.php';
		if(file_exists($api)) include_once $api;

		// Tests if Kunena is installed and if the minimum version requirement is met
		$kunenaVersion = '';

		// Kunena >= 2.0
		if(class_exists('KunenaForum') && KunenaForum::installed() && method_exists('KunenaForum', 'version')){
			$kunenaVersion = KunenaForum::version();
		}// 1.6 <= Kunena < 2.0
		elseif(class_exists('Kunena') && version_compare(Kunena::version(), '1.6', '>=')){
			$kunenaVersion = Kunena::version();
		}// Kunena < 1.6
		else{
			acymailing_enqueueMessage('This plugin does not support Kunena < 1.6', 'error');
			return false;
		}

		// Loads dependencies

		// Kunena >= 2.0
		if(!version_compare($kunenaVersion, '2.0', '<')){
			KunenaFactory::loadLanguage();
			KunenaFactory::loadLanguage('com_kunena.templates');
			KunenaFactory::loadLanguage('com_kunena.views');
			KunenaFactory::loadLanguage('com_kunena', 'admin');
			KunenaFactory::loadLanguage('com_kunena.libraries', 'admin');
			
			acymailing_loadLanguageFile('com_media', JPATH_SITE);
		}else // 1.6 <= Kunena < 2.0
		{
			$paths = array(JPATH_ROOT.DS.'components'.DS.'com_kunena'.DS.'class.kunena.php', JPATH_ROOT.DS.'includes'.DS.'application.php', KUNENA_PATH_LIB.DS.'kunena.link.class.php', KUNENA_PATH_LIB.DS.'kunena.image.class.php', KUNENA_PATH_LIB.DS.'kunena.timeformat.class.php', KUNENA_PATH_FUNCS.DS.'latestx.php', JPATH_ADMINISTRATOR.DS.'components'.DS.'com_kunena'.DS.'libraries'.DS.'html'.DS.'parser.php', JPATH_ADMINISTRATOR.DS.'components'.DS.'com_kunena'.DS.'libraries'.DS.'session.php', JPATH_ADMINISTRATOR.DS.'components'.DS.'com_kunena'.DS.'libraries'.DS.'user.php');

			foreach($paths as $path){
				if(!file_exists($path)){
					acymailing_enqueueMessage('File not found : '.$path, 'error');
					return false;
				}
				include_once($path);
			}

			// Language files
			
			acymailing_loadLanguageFile('com_kunena', JPATH_SITE);
			acymailing_loadLanguageFile('com_kunena', JPATH_SITE.DS.'components'.DS.'com_kunena');
			acymailing_loadLanguageFile('com_kunena.templates', JPATH_SITE.DS.'components'.DS.'com_kunena');
			acymailing_loadLanguageFile('com_kunena.views', JPATH_SITE.DS.'components'.DS.'com_kunena');
			acymailing_loadLanguageFile('com_media', JPATH_SITE);
		}

		$this->kunenaVersion = $kunenaVersion;

		return true;
	}
}
